@@ -1,9 +1,9 @@
 /***************************************************************************
-			collision.h  -  header for the corresponding cpp file
-                         -------------------
-    copyright            : (C) 2005 - 2007 Florian Richter
-						   (C) 2005 Amir Taaki ( Circle Collision tests ) - MIT License
-						   (C) 2005 Magnus Norddahl ( Line Collision tests ) - BSD License
+ * collision.h  -  header for the corresponding cpp file
+ *
+ * Copyright (C) 2005 - 2008 Florian Richter
+ * Copyright (C) 2005 Amir Taaki ( Circle Collision tests ) - MIT License
+ * Copyright (C) 2005 Magnus Norddahl ( Line Collision tests ) - BSD License
  ***************************************************************************/
 /*
    This program is free software; you can redistribute it and/or modify
@@ -15,8 +15,8 @@
    along with this program.  If not, see <http://www.gnu.org/licenses/>.
 */
 
-#ifndef _COLLISION_H_
-#define _COLLISION_H_
+#ifndef SMC_COLLISION_H
+#define SMC_COLLISION_H
 
 #include "../core/globals.h"
 
@@ -48,11 +48,11 @@ public:
 	// add an Object Collision
 	void add( cSprite *obj );
 	// returns true if the given Object Collision was found
-	bool find( cSprite *obj );
+	bool find( const cSprite *obj );
 	// returns the first found sprite if the given Array type was found
-	cSprite *find( ArrayType type );
+	cSprite *find( const ArrayType type );
 	// returns the first found sprite if the given Sprite type was found
-	cSprite *find( SpriteType type );
+	cSprite *find( const SpriteType type );
 	// returns the found collision size
 	unsigned int size( void );
 
@@ -72,9 +72,9 @@ public:
 	 * base - the base sprite
 	 * col - the colliding sprite
 	*/
-	void Set_direction( cSprite *base, cSprite *col );
+	void Set_Direction( cSprite *base, cSprite *col );
 	// returns the colliding object rect
-	GL_rect Get_ColObject_rect( void );
+	GL_rect Get_Collision_Object_Rect( void );
 
 
 	/* if true this is a receiving collision
@@ -99,36 +99,36 @@ typedef vector<cObjectCollision *> ObjectCollisionList;
  * base - the base sprite
  * col - the colliding sprite
 */
-ObjectDirection Get_col_direction( cSprite *base, cSprite *col );
+ObjectDirection Get_Collision_Direction( cSprite *base, cSprite *col );
 
 // returns true if a collision is on the top
-bool Is_collision_top( GL_rect *base_rect, GL_rect *col_rect );
+bool Is_Collision_Top( const GL_rect *base_rect, const GL_rect *col_rect );
 // returns true if a collision is on the bottom
-bool Is_collision_bottom( GL_rect *base_rect, GL_rect *col_rect );
+bool Is_Collision_Bottom( const GL_rect *base_rect, const GL_rect *col_rect );
 // returns true if a collision is on the left
-bool Is_collision_left( GL_rect *base_rect, GL_rect *col_rect );
+bool Is_Collision_Left( const GL_rect *base_rect, const GL_rect *col_rect );
 // returns true if a collision is on the right
-bool Is_collision_right( GL_rect *base_rect, GL_rect *col_rect );
+bool Is_Collision_Right( const GL_rect *base_rect, const GL_rect *col_rect );
 
 /* Returns the Collision Type from the Array Type
  * if unknown returns CO_NOTHING
 */
-ObjectCollisionType Get_CollisionType( ArrayType array_type );
+ObjectCollisionType Get_Collision_Type( ArrayType array_type );
 
-/* Function: Col_Box
+/*
  * Bounding box collision test
  * Checks if the first rect intersects with the second
 */
-bool Col_Box( GL_rect *a, GL_rect *b );
-bool Col_Box( SDL_Rect *a, GL_rect *b );
+bool Col_Box( const GL_rect *a, const GL_rect *b );
+bool Col_Box( const SDL_Rect *a, const GL_rect *b );
 
-/* Function: Col_Box_full
+/*
  * Bounding box collision test (SDL_Rect)
  * Checks if the first rect intersects completely with the second
 */
-bool Col_Box_full( SDL_Rect *a, SDL_Rect *b );
+bool Col_Box_full( const SDL_Rect *a, const SDL_Rect *b );
 
-/* Function: Col_Circle
+/*
  * tests whether 2 circles intersect
  *
  * Parameters:
@@ -137,24 +137,21 @@ bool Col_Box_full( SDL_Rect *a, SDL_Rect *b );
  * (allow distance between circles of offset)
 */
 bool Col_Circle( float x1, float y1, float r1, float x2, float y2, float r2, int offset = 1);
-/* Function: Col_Circle
+/*
  * a circle intersection detection algorithm that will use
  * the position of the center of the surface as the center of
  * the circle and approximate the radius using the width and height
  * of the surface (for example a rect of 4x6 would have r = 2.5).
 */
-bool Col_Circle( GL_Surface *surface1, SDL_Rect *a, GL_Surface *surface2, SDL_Rect *b, int offset = 0 );
-bool Col_Circle( GL_Surface *a, float x1, float y1, GL_Surface *b, float x2, float y2, int offset );
+bool Col_Circle( cGL_Surface *surface1, SDL_Rect *a, cGL_Surface *surface2, SDL_Rect *b, int offset = 0 );
+bool Col_Circle( cGL_Surface *a, float x1, float y1, cGL_Surface *b, float x2, float y2, int offset );
 
-// Function: distance_to_line
 // returns the distance from a point to the given line
-float distance_to_line( float x, float y, GL_line *line );
-// Function: get_lineintersection
+float Distance_to_Line( float x, float y, GL_line *line );
 // returns the intersection point between the lines
-GL_point get_lineintersection( GL_line *line1, GL_line *line2 );
-// Function: Col_line
+GL_point Get_Line_Intersection( GL_line *line1, GL_line *line2 );
 // returns true if the lines intersect
-bool Col_line( GL_line *line1, GL_line *line2, bool collinear_intersect = 0 );
+bool Col_Line( GL_line *line1, GL_line *line2, bool collinear_intersect = 0 );
 
 /* *** *** *** *** *** *** *** *** *** *** *** *** *** *** *** *** *** */
 
