@@ -1,7 +1,7 @@
 /***************************************************************************
-	framerate.cpp  -  Framerate independant class and a time correcting function
-                             -------------------
-	copyright                : (C) 2003 - 2007 by Florian Richter
+ * framerate.cpp  -  Framerate independant motion control
+ *
+ * Copyright (C) 2003 - 2008 Florian Richter
  ***************************************************************************/
 /*
    This program is free software; you can redistribute it and/or modify
@@ -16,6 +16,46 @@
 #include "../core/globals.h"
 #include "../core/framerate.h"
 
+
+/* *** *** *** *** *** *** cPerformance_Timer *** *** *** *** *** *** *** *** *** *** *** */
+
+cPerformance_Timer :: cPerformance_Timer( void )
+{
+	Reset();
+}
+
+cPerformance_Timer :: ~cPerformance_Timer( void )
+{
+
+}
+
+void cPerformance_Timer :: Reset( void )
+{
+	frame_counter = 0;
+	ms_counter = 0;
+	ms = 0;
+}
+
+void cPerformance_Timer :: Update( void )
+{
+	// count frame
+	frame_counter++;
+
+	// add milliseconds
+	Uint32 new_ticks = SDL_GetTicks();
+	ms_counter += new_ticks - pFramerate->perf_last_ticks;
+	pFramerate->perf_last_ticks = new_ticks;
+
+	// counted 100 frames
+	if( frame_counter >= 100 )
+	{
+		ms = ms_counter;
+		frame_counter = 0;
+		ms_counter = 0;
+	}
+}
+
+
 /* *** *** *** *** *** *** cFramerate *** *** *** *** *** *** *** *** *** *** *** */
 
 cFramerate :: cFramerate( float tfps /* = DESIRED_FPS */ )
@@ -28,19 +68,36 @@ cFramerate :: cFramerate( float tfps /* = DESIRED_FPS */ )
 
 	force_speedfactor = 0;
 
+	perf_last_ticks = 0;
+
+	// create performance timers
+	for( unsigned int i = 0; i < 20; i++ )
+	{
+		perf_timer.push_back( new cPerformance_Timer() );
+	}
+
 	Init( tfps );
 }
 
 cFramerate :: ~cFramerate ( void )
 {
-	//
+	// clear performance timer
+	for( Performance_Timer_List::iterator itr = perf_timer.begin(), itr_end = perf_timer.end(); itr != itr_end; ++itr )
+	{
+		delete *itr;
+	}
+
+	perf_timer.clear();
 }
 
 void cFramerate :: Init( float tfps )
 {
-	targetfps = tfps;
+	fps_target = tfps;
 	maxspeedfactor = tfps * 0.15f;
-	framedelay = SDL_GetTicks();
+	currentticks = SDL_GetTicks();
+	framedelay = currentticks;
+	fps_average_framedelay = currentticks;
+	frames_counted = 0;
 }
 
 void cFramerate :: Update( void )
@@ -64,7 +121,7 @@ void cFramerate :: Update( void )
 		else
 		{
 			// frame speedfactor calculation
-			speedfactor = static_cast<float>(( currentticks - framedelay ) / ( 1000 / targetfps ));
+			speedfactor = static_cast<float>(( currentticks - framedelay ) / ( 1000 / fps_target ));
 		}
 
 		if( speedfactor <= 0 )
@@ -77,23 +134,21 @@ void cFramerate :: Update( void )
 		}
 	}
 
-	// current frame fps
-	fps = targetfps / speedfactor;
+	// speedfactor based fps
+	fps = fps_target / speedfactor;
 	
 	// calculate average fps every second
 	if( currentticks - fps_average_framedelay > 1000 )
 	{
-		fps_average = fps_average_counter / fps_average_times_counted;
+		fps_average = frames_counted;
 
-		fps_average_framedelay = static_cast<float>(currentticks);
-		fps_average_times_counted = 0;
-		fps_average_counter = 0;
+		fps_average_framedelay += 1000;
+		frames_counted = 0;
 	}
 	// count a fps
 	else
 	{
-		fps_average_times_counted++;
-		fps_average_counter += fps;
+		frames_counted++;
 	}
 
 	// best fps
@@ -115,25 +170,27 @@ void cFramerate :: Reset( void )
 	framedelay = SDL_GetTicks();
 	speedfactor = 0.1f;
 	fps_best = 0;
-	fps_worst = 100;
+	fps_worst = 100000;
 	fps_average = 0;
+
+	// reset performance timer
+	for( Performance_Timer_List::iterator itr = perf_timer.begin(), itr_end = perf_timer.end(); itr != itr_end; ++itr )
+	{
+		(*itr)->Reset();
+	}
 }
 
-void cFramerate :: SetMaxSpeedFactor( float maximum )
+void cFramerate :: Set_Max_Speed_Factor( float maximum )
 {
 	maxspeedfactor = maximum;
 }
 
-/* Set the given fixed speedfactor
- * if value is 0 no fixed speedfactor will be used
-*/
 void cFramerate :: Set_Fixed_Speedfacor( float val )
 {
 	force_speedfactor = val;
 }
 
-/* Fixed framerate method */
-void CorrectFrameTime( unsigned int fps )
+void Correct_Frame_Time( unsigned int fps )
 {
 	static Uint32 stime = 0;
 	
