@@ -1,7 +1,7 @@
 /***************************************************************************
-                main.h  -  header for the corresponding cpp file
-                             -------------------
-    copyright            :	(C) 2003 - 2007 by Florian Richter
+ * main.h  -  header for the corresponding cpp file
+ *
+ * Copyright (C) 2003 - 2008 Florian Richter
  ***************************************************************************/
 /*
    This program is free software; you can redistribute it and/or modify
@@ -13,34 +13,30 @@
    along with this program.  If not, see <http://www.gnu.org/licenses/>.
 */
 
-#ifndef __MAIN_H__
-#define __MAIN_H__
+#ifndef SMC_MAIN_H
+#define SMC_MAIN_H
 
 #include "../core/globals.h"
 
 /* *** *** *** *** *** *** *** *** *** *** *** *** *** *** *** *** *** */
 
-// Function : InitGame
 // Initialize everything, called before everything else
 // Seed random numbers, init SDL, OpenGL, CEGUI, load preferences, and create globals
-void InitGame( void );
+void Init_Game( void );
 
-// Function : ExitGame
 // Delete globals. Also saves preferences and closes SDL
-void ExitGame( void );
+void Exit_Game( void );
 
-/* Function : Handle_Input_Global
+/*
  * Top-level input function. Calls either KeyDown, KeyUp,
  * or passes control to pMouseCursor or pJoystick
  * Returns true if the event was handled.
 */ 
 bool Handle_Input_Global( SDL_Event *ev );
 
-// Function : Update_Game
 // Called continuously from Game Loop. Update current game state
 void Update_Game( void );
 
-// Function : Draw_Game
 // Called continuously from Game Loop. Draw current game state
 void Draw_Game( void );
 
