@@ -1,8 +1,7 @@
 /***************************************************************************
-           turtle_boss.cpp  -  turtle enemy class
-                             -------------------
-    copyright            :	(C) 2003 - 2007 by Florian Richter
-							(C) 2006 by Tobias Maasland
+ * turtle_boss.cpp  -  turtle enemy class
+ *
+ * Copyright (C) 2003 - 2008 Florian Richter
  ***************************************************************************/
 /*
    This program is free software; you can redistribute it and/or modify
@@ -22,20 +21,22 @@
 #include "../../level/level.h"
 #include "../../gui/hud.h"
 #include "../../video/gl_surface.h"
+#include "../../core/sprite_manager.h"
+#include "../../core/i18n.h"
 
 /* *** *** *** *** *** *** cTurtleBoss *** *** *** *** *** *** *** *** *** *** *** */
 
 cTurtleBoss :: cTurtleBoss( float x, float y )
 : cEnemy( x, y )
 {
-	Init();
+	cTurtleBoss::Init();
 }
 
-cTurtleBoss :: cTurtleBoss( XMLAttributes &attributes )
+cTurtleBoss :: cTurtleBoss( CEGUI::XMLAttributes &attributes )
 : cEnemy()
 {
-	Init();
-	Create_from_Stream( attributes );
+	cTurtleBoss::Init();
+	cTurtleBoss::Create_from_Stream( attributes );
 }
 
 cTurtleBoss :: ~cTurtleBoss( void )
@@ -65,9 +66,9 @@ void cTurtleBoss :: Init( void )
 
 	max_hits = 3;
 	max_downgrade_counts = 3;
-	max_downgrade_time = 2.5f;
+	shell_time = 2.5f;
 
-	run_time = 0;
+	run_time_counter = 0;
 }
 
 cTurtleBoss *cTurtleBoss :: Copy( void )
@@ -77,24 +78,25 @@ cTurtleBoss *cTurtleBoss :: Copy( void )
 	turtle->Set_Color( color_type );
 	turtle->Set_Max_Hits( max_hits );
 	turtle->Set_Max_Downgrade_Counts( max_downgrade_counts );
-	turtle->Set_Max_Downgrade_Time( max_downgrade_time );
+	turtle->Set_Shell_Time( shell_time );
 
 	return turtle;
 }
 
-void cTurtleBoss :: Create_from_Stream( XMLAttributes &attributes )
+void cTurtleBoss :: Create_from_Stream( CEGUI::XMLAttributes &attributes )
 {
 	// position
 	Set_Pos( static_cast<float>(attributes.getValueAsInteger( "posx" )), static_cast<float>(attributes.getValueAsInteger( "posy" )), 1 );
 	// direction
-	Set_Direction( Get_Direction_id( attributes.getValueAsString( "direction", Get_Direction_name( start_direction ) ).c_str() ), 1 );
+	Set_Direction( Get_Direction_Id( attributes.getValueAsString( "direction", Get_Direction_Name( start_direction ) ).c_str() ), 1 );
 	// color
-	Set_Color( (DefaultColor)Get_Color_id( attributes.getValueAsString( "color", Get_Color_name( color_type ) ).c_str() ) );
-
-	// boss data
+	Set_Color( static_cast<DefaultColor>(Get_Color_Id( attributes.getValueAsString( "color", Get_Color_Name( color_type ) ).c_str() )) );
+	// max hits
 	Set_Max_Hits( attributes.getValueAsInteger( "max_hit_count", max_hits ) );
+	// max downgrade count
 	Set_Max_Downgrade_Counts( attributes.getValueAsInteger( "max_downgrade_count", max_downgrade_counts ) );
-	Set_Max_Downgrade_Time( attributes.getValueAsFloat( "max_downgrade_time", max_downgrade_time ) );
+	// shell time
+	Set_Shell_Time( attributes.getValueAsFloat( "shell_time", shell_time ) );
 }
 
 void cTurtleBoss :: Save_to_Stream( ofstream &file )
@@ -108,13 +110,15 @@ void cTurtleBoss :: Save_to_Stream( ofstream &file )
 	file << "\t\t<Property name=\"posx\" value=\"" << static_cast<int>(startposx) << "\" />" << std::endl;
 	file << "\t\t<Property name=\"posy\" value=\"" << static_cast<int>(startposy) << "\" />" << std::endl;
 	// color
-	file << "\t\t<Property name=\"color\" value=\"" << Get_Color_name( color_type ) << "\" />" << std::endl;
+	file << "\t\t<Property name=\"color\" value=\"" << Get_Color_Name( color_type ) << "\" />" << std::endl;
 	// direction
-	file << "\t\t<Property name=\"direction\" value=\"" << Get_Direction_name( start_direction ) << "\" />" << std::endl;
-	// boss data
+	file << "\t\t<Property name=\"direction\" value=\"" << Get_Direction_Name( start_direction ) << "\" />" << std::endl;
+	// max hit count
 	file << "\t\t<Property name=\"max_hit_count\" value=\"" << max_hits << "\" />" << std::endl;
+	// max downgrade count
 	file << "\t\t<Property name=\"max_downgrade_count\" value=\"" << max_downgrade_counts << "\" />" << std::endl;
-	file << "\t\t<Property name=\"max_downgrade_time\" value=\"" << max_downgrade_time << "\" />" << std::endl;
+	// shell time
+	file << "\t\t<Property name=\"shell_time\" value=\"" << shell_time << "\" />" << std::endl;
 
 	// end enemy
 	file << "\t</enemy>" << std::endl;
@@ -140,13 +144,13 @@ void cTurtleBoss :: Set_Max_Downgrade_Counts( int nmax_downgrade_counts )
 	}
 }
 
-void cTurtleBoss :: Set_Max_Downgrade_Time( float nmax_downgrade_time )
+void cTurtleBoss :: Set_Shell_Time( float nmax_downgrade_time )
 {
-	max_downgrade_time = nmax_downgrade_time;
+	shell_time = nmax_downgrade_time;
 
-	if( max_downgrade_time < 0 )
+	if( shell_time < 0 )
 	{
-		max_downgrade_time = 0;
+		shell_time = 0;
 	}
 }
 
@@ -183,18 +187,18 @@ void cTurtleBoss :: Set_Direction( ObjectDirection dir, bool new_start_direction
 		}
 	}
 
-	Update_Rotation_velx( new_start_direction );
-
-	// angry turtle
-	if( turtle_state == TURTLEBOSS_STAND_ANGRY )
-	{
-		velx = 0;
-	}
+	Update_Rotation_Hor_velx( new_start_direction );
 
 	if( new_start_direction )
 	{
 		Create_Name();
 	}
+
+	// if angry turtle
+	if( turtle_state == TURTLEBOSS_STAND_ANGRY )
+	{
+		velx = 0;
+	}
 }
 
 void cTurtleBoss :: Set_Color( DefaultColor col )
@@ -243,7 +247,14 @@ void cTurtleBoss :: Turn_Around( ObjectDirection col_dir /* = DIR_UNDEFINED */ )
 {
 	cEnemy::Turn_Around( col_dir );
 
-	Update_Rotation_velx();
+	if( turtle_state == TURTLEBOSS_WALK )
+	{
+		// hack : disable turn image
+		//walk_count = 0;
+		//Set_Image( 4 );
+	}
+
+	Update_Rotation_Hor_velx();
 }
 
 void cTurtleBoss :: DownGrade( bool force /* = 0 */ )
@@ -267,7 +278,7 @@ void cTurtleBoss :: DownGrade( bool force /* = 0 */ )
             }
 
 			// state change
-		    if( hits == max_hits )
+		    if( hits >= max_hits )
 		    {
                 counter = 0;
 
@@ -277,20 +288,7 @@ void cTurtleBoss :: DownGrade( bool force /* = 0 */ )
 				// die
                 if( downgrade_counts == max_downgrade_counts )
                 {
-					// fade out music
-					pAudio->FadeOutMusic( 500 );
-					// play finish music
-					pAudio->PlayMusic( "game/courseclear.ogg", 0, 0 );
-
-					// set shell image
-					Set_Image( 5 );
-
-					// death state
 					Set_Dead( 1 );
-					massivetype = MASS_PASSIVE;
-					counter = 8;
-					velx = 0;
-					vely = 0;
                 }
 				// downgrade
                 else
@@ -324,22 +322,35 @@ void cTurtleBoss :: DownGrade( bool force /* = 0 */ )
 			}
 
 			Update_Direction();
-			Update_Rotation_velx();
+			Update_Rotation_Hor_velx();
 		}
 	}
 	// falling death
 	else
 	{
+		// die
 		Set_Dead( 1 );
-		counter = 8;
-		massivetype = MASS_PASSIVE;
 
 		if( turtle_state == TURTLEBOSS_WALK )
 		{
 			Move( 0, images[0]->h - images[5]->h, 1 );
 		}
+	}
 
+	if( dead )
+	{
+		// fade out music
+		pAudio->Fadeout_Music( 500 );
+		// play finish music
+		pAudio->Play_Music( "game/courseclear.ogg", 0, 0 );
+
+		// set shell image
 		Set_Image( 5 );
+
+		massivetype = MASS_PASSIVE;
+		counter = 8;
+		velx = 0;
+		vely = 0;
 	}
 }
 
@@ -347,66 +358,53 @@ void cTurtleBoss :: DieStep( void )
 {
 	counter += pFramerate->speedfactor * 0.5f;
 
-	// if not below the screen
-	if( posy < GAME_RES_H + col_rect.h )
+	if( scalex > 0.1f )
 	{
-		if( scalex > 0.1f )
+		float speed_x = pFramerate->speedfactor * 10;
+
+		if( direction == DIR_LEFT )
 		{
-			float speed_x = pFramerate->speedfactor * 10;
-
-			if( direction == DIR_LEFT )
-			{
-				speed_x *= -1;
-			}
-
-			Add_RotationZ( speed_x );
-			Add_Scale( -pFramerate->speedfactor * 0.025f );
-
-			// finished scale out animation
-			if( scalex <= 0.1f )
-			{
-				// sound
-				pAudio->PlaySound( "enemy/turtle/shell/hit.ogg" );
-
-				// animation
-				cParticleAnimation *anim = new cParticleAnimation( posx, posy );
-				anim->Set_Image( pVideo->Get_Surface( "animation/particles/star.png" ) );
-				anim->Set_Quota( 30 );
-				anim->Set_ZPos( posz + 0.000001f );
-				anim->Set_ConstRotationZ( 0.9f, 12 );
-				anim->Set_Time_to_Live( 1 );
-				anim->Set_Speed( 1, 4 );
-				anim->Set_Scale( 0.4f, 0.3f );
-				anim->Set_Color( orange, Color( static_cast<Uint8>(6), 60, 20 ) );
-				anim->Set_Blending( BLEND_ADD );
-				pAnimationManager->Add( anim );
-
-				// set empty image
-				cMovingSprite::Set_Image( NULL, 0, 0 );
-				// reset counter
-				counter = 0;
-			}
+			speed_x *= -1;
 		}
-		// after scale animation
-		else
+
+		Add_Rotation_Z( speed_x );
+		Add_Scale( -pFramerate->speedfactor * 0.025f );
+
+		// finished scale out animation
+		if( scalex <= 0.1f )
 		{
-			// wait some time
-			if( counter > 25 )
-			{
-				// next level
-				pPlayer->Goto_next_Level();
-			}
+			// sound
+			pAudio->Play_Sound( "enemy/turtle/shell/hit.ogg" );
+
+			// animation
+			cParticle_Emitter *anim = new cParticle_Emitter();
+			anim->Set_Pos( posx, posy );
+			anim->Set_Image( pVideo->Get_Surface( "animation/particles/star.png" ) );
+			anim->Set_Quota( 30 );
+			anim->Set_Pos_Z( posz + 0.000001f );
+			anim->Set_Const_Rotation_Z( -6, 12 );
+			anim->Set_Time_to_Live( 1 );
+			anim->Set_Speed( 1, 4 );
+			anim->Set_Scale( 0.4f, 0.3f );
+			anim->Set_Color( orange, Color( static_cast<Uint8>(6), 60, 20 ) );
+			anim->Set_Blending( BLEND_ADD );
+			pAnimation_Manager->Add( anim );
+
+			// set empty image
+			cMovingSprite::Set_Image( NULL, 0, 0 );
+			// reset counter
+			counter = 0;
 		}
 	}
-	// if below disable
+	// after scale animation
 	else
 	{
-		state = STA_STAY;
-		turtle_state = TURTLEBOSS_DEAD;
-		Set_Visible( 0 );
-		rotz = 0;
-		velx = 0;
-		vely = 0;
+		// wait some time
+		if( counter > 25 )
+		{
+			// next level
+			pPlayer->Goto_Next_Level();
+		}
 	}
 }
 
@@ -424,27 +422,27 @@ void cTurtleBoss :: Update( void )
 	{
 		walk_count += pFramerate->speedfactor * 0.3f;
 
-		if( walk_count >= 4 )
-		{
-			walk_count = 0;
-
-			// if turn around image force the new
-			if( curr_img == 4 )
-			{
-				Set_Image( static_cast<int>(walk_count) );
-				Update_Rotation_velx();
-			}
-		}
-
-		// if turn around image
+		// if not turn around image
 		if( curr_img != 4 )
 		{
+			if( walk_count >= 4 )
+			{
+				walk_count = 0;
+			}
+
 			Set_Image( static_cast<int>(walk_count) );
 		}
+		// turn around image
 		else
 		{
+			// force the new image
+			if( walk_count >= 4 )
+			{
+				Set_Image( static_cast<int>(walk_count) );
+				Update_Rotation_Hor_velx();
+			}
 			// rotate the turn image
-			if( walk_count >= 2 )
+			else if( walk_count >= 2 )
 			{
 				if( velx < 0 )
 				{
@@ -503,13 +501,13 @@ void cTurtleBoss :: Update( void )
 	// moving shell
 	else if( turtle_state == TURTLEBOSS_SHELL_RUN )
 	{
-        run_time += pFramerate->speedfactor;
+        run_time_counter += pFramerate->speedfactor;
 		// time = seconds since start
-        float time = run_time / DESIRED_FPS;
+        float time = run_time_counter / speedfactor_fps;
 
-        if( time > max_downgrade_time )
+        if( time > shell_time )
 		{
-		    run_time = 0;
+		    run_time_counter = 0;
             Activate_Turtle();
 
             return;
@@ -584,7 +582,7 @@ void cTurtleBoss :: Update( void )
 		    state = STA_RUN;
 
 			// shell attack sound
-			pAudio->PlaySound( "enemy/boss/turtle/shell_attack.ogg" );
+			pAudio->Play_Sound( "enemy/boss/turtle/shell_attack.ogg" );
 
 			// throw more fireballs with downgrades
 		    Throw_Fireballs( 6 + ( downgrade_counts * 2 ) );
@@ -609,26 +607,29 @@ void cTurtleBoss :: Update( void )
 
 void cTurtleBoss :: Throw_Fireballs( unsigned int amount /* = 6 */ )
 {
+	// start angle
 	float ball_angle = -180;
+	// move 180 degrees
+	float step_size = 180 / static_cast<float>(amount);
 
 	for( unsigned int i = 0; i < amount; i++ )
 	{
-		ball_angle += 180 / amount; // 10 * 18 = 180 degrees
+		// add step size to angle
+		ball_angle += step_size;
 
-		cBall *ball = new cBall( posx + col_rect.w / 2, posy + col_rect.h / 2, 0, 0, this, FIREBALL_EXPLOSION );
+		cBall *ball = new cBall( posx + col_rect.w / 2, posy + col_rect.h / 2, this, FIREBALL_EXPLOSION );
 		ball->Set_Direction( ball_angle, 15 );
 		ball->Col_Move( ball->velx * 2, ball->vely * 2, 1 );
-
-		pLevel->pSprite_Manager->Add( ball );
+		pActive_Sprite_Manager->Add( ball );
 	}
 
-	cFireAnimation *anim = new cFireAnimation( posx + ( col_rect.w / 2 ), posy + ( col_rect.h / 3 ), 10 );
-	anim->Set_FadingSpeed( 0.15f );
-	anim->Set_ZPos( posz + 0.000001f );
-	pAnimationManager->Add( anim );
+	cAnimation_Fireball *anim = new cAnimation_Fireball( posx + ( col_rect.w / 2 ), posy + ( col_rect.h / 3 ), 10 );
+	anim->Set_Fading_Speed( 0.15f );
+	anim->Set_Pos_Z( posz + 0.000001f );
+	pAnimation_Manager->Add( anim );
 }
 
-bool cTurtleBoss :: is_Update_valid( void )
+bool cTurtleBoss :: Is_Update_Valid( void )
 {
 	if( dead || freeze_counter )
 	{
@@ -711,7 +712,7 @@ unsigned int cTurtleBoss :: Validate_Collision( cSprite *obj )
 
 		return 2;
 	}
-	if( obj->type == TYPE_ENEMYSTOPPER )
+	if( obj->type == TYPE_ENEMY_STOPPER )
 	{
 		if( turtle_state == TURTLEBOSS_WALK )
 		{
@@ -722,8 +723,8 @@ unsigned int cTurtleBoss :: Validate_Collision( cSprite *obj )
 	}
 	if( obj->massivetype == MASS_HALFMASSIVE )
 	{
-		// if moving downwards and object is on top
-		if( vely >= 0 && is_onTop( obj ) )
+		// if moving downwards and the object is on bottom
+		if( vely >= 0 && Is_on_Top( obj ) )
 		{
 			return 2;
 		}
@@ -747,32 +748,33 @@ void cTurtleBoss :: Handle_Collision_Player( cObjectCollision *collision )
 
 			if( hits + 1 == max_hits )
 			{
-				pAudio->PlaySound( "enemy/boss/turtle/big_hit.ogg" );
+				pAudio->Play_Sound( "enemy/boss/turtle/big_hit.ogg" );
 			}
 			else
 			{
-				pAudio->PlaySound( "enemy/boss/turtle/hit.ogg" );
+				pAudio->Play_Sound( "enemy/boss/turtle/hit.ogg" );
 			}
 		}
 		else if( turtle_state == TURTLEBOSS_SHELL_STAND )
 		{
 			pointsdisplay->Add_Points( 100, pPlayer->posx, pPlayer->posy );
-			pAudio->PlaySound( "enemy/turtle/shell/hit.ogg" );
+			pAudio->Play_Sound( "enemy/turtle/shell/hit.ogg" );
 		}
 		else if( turtle_state == TURTLEBOSS_SHELL_RUN )
 		{
 			pointsdisplay->Add_Points( 50, pPlayer->posx, pPlayer->posy );
-			pAudio->PlaySound( "enemy/turtle/shell/hit.ogg" );
+			pAudio->Play_Sound( "enemy/turtle/shell/hit.ogg" );
 		}
 
 		// animation
-		cParticleAnimation *anim = new cParticleAnimation( posx + ( col_rect.w / 2 ), posy + ( col_rect.h / 2 ) );
+		cParticle_Emitter *anim = new cParticle_Emitter();
+		anim->Set_Pos( posx + ( col_rect.w / 2 ), posy + ( col_rect.h / 2 ) );
 		Generate_Hit_Animation( anim );
 
 		anim->Set_Speed( 4, 0.8f );
 		anim->Set_Scale( 0.9f );
 		// add animation
-		pAnimationManager->Add( anim );
+		pAnimation_Manager->Add( anim );
 
 		DownGrade();
 
@@ -799,32 +801,35 @@ void cTurtleBoss :: Handle_Collision_Player( cObjectCollision *collision )
 	{
 		if( turtle_state == TURTLEBOSS_WALK )
 		{
-			pPlayer->DownGrade();
+			pPlayer->DownGrade_Player();
 			Turn_Around( collision->direction );
 		}
 		else if( turtle_state == TURTLEBOSS_SHELL_STAND )
 		{
-			pAudio->PlaySound( "enemy/turtle/shell/hit.ogg" );
+			pAudio->Play_Sound( "enemy/turtle/shell/hit.ogg" );
 			DownGrade();
 
-			cParticleAnimation *anim = NULL;
+			cParticle_Emitter *anim = NULL;
 
 			if( collision->direction == DIR_RIGHT )
 			{
-				anim = new cParticleAnimation( posx + col_pos.x + col_rect.w, posy + ( col_rect.h / 2 ) );
-				anim->Set_DirectionRange( 90, 180 );
+				anim = new cParticle_Emitter();
+				anim->Set_Pos( posx + col_pos.x + col_rect.w, posy + ( col_rect.h / 2 ) );
+				anim->Set_Direction_Range( 90, 180 );
 				velx = -speed_shell;
 			}
 			else if( collision->direction == DIR_LEFT )
 			{
-				anim = new cParticleAnimation( posx, posy + ( col_rect.h / 2 ) );
-				anim->Set_DirectionRange( 270, 180 );
+				anim = new cParticle_Emitter();
+				anim->Set_Pos( posx, posy + ( col_rect.h / 2 ) );
+				anim->Set_Direction_Range( 270, 180 );
 				velx = speed_shell;
 			}
 			else
 			{
-				anim = new cParticleAnimation( posx + ( col_rect.w / 2 ), posy + col_pos.y + col_rect.h );
-				anim->Set_DirectionRange( 180, 180 );
+				anim = new cParticle_Emitter();
+				anim->Set_Pos( posx + ( col_rect.w / 2 ), posy + col_pos.y + col_rect.h );
+				anim->Set_Direction_Range( 180, 180 );
 
 				// if player is on the left side
 				if( ( pPlayer->col_rect.w / 2 ) + pPlayer->posx < ( col_rect.w / 2 ) + posx )
@@ -840,22 +845,22 @@ void cTurtleBoss :: Handle_Collision_Player( cObjectCollision *collision )
 
 			anim->Set_Image( pVideo->Get_Surface( "animation/particles/light.png" ) );
 			anim->Set_Quota( 4 );
-			anim->Set_ZPos( posz + 0.0001f );
+			anim->Set_Pos_Z( posz + 0.0001f );
 			anim->Set_Time_to_Live( 0.3f );
 			anim->Set_Speed( 4, 0.5f );
 			anim->Set_Scale( 0.8f );
 			anim->Set_Fading_Size( 1 );
 			anim->Set_Color( Color( static_cast<Uint8>(254), 200, 100 ) );
-			pAnimationManager->Add( anim );
+			pAnimation_Manager->Add( anim );
 			
 			Update_Direction();
 
-			playercounter = DESIRED_FPS * 0.13f;
+			playercounter = speedfactor_fps * 0.13f;
 
 			// small upwards kick
 			if( collision->direction == DIR_BOTTOM )
 			{
-				vely = -5 + pPlayer->vely / 3;
+				vely = -5 + (pPlayer->vely * 0.3f);
 			}
 		}
 		else if( turtle_state == TURTLEBOSS_SHELL_RUN )
@@ -866,13 +871,13 @@ void cTurtleBoss :: Handle_Collision_Player( cObjectCollision *collision )
 				// small upwards kick
 				if( collision->direction == DIR_BOTTOM )
 				{
-					vely = -5 + pPlayer->vely / 3;
+					vely = -5 + (pPlayer->vely * 0.3f);
 				}
 			}
 			// other directions downgrade
 			else
 			{
-				pPlayer->DownGrade();
+				pPlayer->DownGrade_Player();
 				Turn_Around( collision->direction );
 			}
 		}
@@ -881,12 +886,12 @@ void cTurtleBoss :: Handle_Collision_Player( cObjectCollision *collision )
 
 void cTurtleBoss :: Handle_Collision_Enemy( cObjectCollision *collision )
 {
-	cEnemy *enemy = static_cast<cEnemy *>(pLevel->pSprite_Manager->Get_Pointer( collision->number ));
+	cEnemy *enemy = static_cast<cEnemy *>(pActive_Sprite_Manager->Get_Pointer( collision->number ));
 
 	if( turtle_state == TURTLEBOSS_SHELL_STAND )
 	{
 		// if able to collide
-		if( state == STA_OBJ_LINKED || vely < -5 )
+		if( vely < -5 )
 		{
 			// don't collide with already dead enemies
 			if( enemy->dead )
@@ -895,11 +900,10 @@ void cTurtleBoss :: Handle_Collision_Enemy( cObjectCollision *collision )
 			}
 
 			// hit enemy
-			pAudio->PlaySound( enemy->kill_sound );
+			pAudio->Play_Sound( enemy->kill_sound );
 			pointsdisplay->Add_Points( enemy->kill_points, posx + image->w / 3, posy - 5, "", static_cast<Uint8>(255), 1 );
 			enemy->DownGrade( 1 );
 
-			DownGrade( 1 );
 			pPlayer->Add_Kill_Multiplier();
 		}
 	}
@@ -912,7 +916,7 @@ void cTurtleBoss :: Handle_Collision_Enemy( cObjectCollision *collision )
 		}
 
 		// hit enemy
-		pAudio->PlaySound( enemy->kill_sound );
+		pAudio->Play_Sound( enemy->kill_sound );
 		pointsdisplay->Add_Points( enemy->kill_points, posx + image->w / 3, posy - 5, "", static_cast<Uint8>(255), 1 );
 		enemy->DownGrade( 1 );
 
@@ -930,7 +934,7 @@ void cTurtleBoss :: Handle_Collision_Enemy( cObjectCollision *collision )
 			}
 
 			// hit enemy
-			pAudio->PlaySound( enemy->kill_sound );
+			pAudio->Play_Sound( enemy->kill_sound );
 			pointsdisplay->Add_Points( enemy->kill_points, posx + image->w / 3, posy - 5, "", static_cast<Uint8>(255), 1 );
 			enemy->DownGrade( 1 );
 		}
@@ -946,41 +950,37 @@ void cTurtleBoss :: Handle_Collision_Massive( cObjectCollision *collision )
 {
 	if( turtle_state == TURTLEBOSS_WALK )
 	{
-		if( collision->direction == DIR_RIGHT || collision->direction == DIR_LEFT )
-		{
-			// hack : disable turn image
-			//Set_Image( 4 );
-
-			//walk_count = 0;
-			Update_Rotation_velx();
-		}
+		//
 	}
 	else if( turtle_state == TURTLEBOSS_SHELL_RUN )
 	{
 		if( collision->direction == DIR_RIGHT || collision->direction == DIR_LEFT )
 		{
-			cSprite *col_object = pLevel->pSprite_Manager->Get_Pointer( collision->number );
+			cSprite *col_object = pActive_Sprite_Manager->Get_Pointer( collision->number );
 
 			// animation
-			cParticleAnimation *anim = NULL;
+			cParticle_Emitter *anim = NULL;
 			if( collision->direction == DIR_RIGHT )
 			{
-				anim = new cParticleAnimation( col_object->posx + col_object->col_pos.x + 4, posy + ( col_rect.h / 1.35f ) );
-				anim->Set_DirectionRange( 140, 100 );
+				anim = new cParticle_Emitter();
+				anim->Set_Pos( col_object->posx + col_object->col_pos.x + 4, posy + ( col_rect.h / 1.35f ) );
+				anim->Set_Direction_Range( 140, 100 );
 			}
 			else
 			{
-				anim = new cParticleAnimation( col_object->posx + col_object->col_pos.x + col_object->col_rect.w - 4, posy + ( col_rect.h / 1.35f ) );
-				anim->Set_DirectionRange( 320, 100 );
+				anim = new cParticle_Emitter();
+				anim->Set_Pos( col_object->posx + col_object->col_pos.x + col_object->col_rect.w - 4, posy + ( col_rect.h / 1.35f ) );
+				anim->Set_Direction_Range( 320, 100 );
 			}
 
+			anim->Set_Image( pVideo->Get_Surface( "animation/particles/smoke.png" ) );
 			anim->Set_Quota( 5 );
 			anim->Set_Time_to_Live( 0.3f );
-			anim->Set_ZPos( col_object->posz - 0.0001f, 0.0002f );
+			anim->Set_Pos_Z( col_object->posz - 0.0001f, 0.0002f );
 			anim->Set_Speed( 1, 1 );
 			anim->Set_Scale( 0.5f, 0.4f );
 			// add animation
-			pAnimationManager->Add( anim );
+			pAnimation_Manager->Add( anim );
 		}
 
 		// active object collision
@@ -998,7 +998,7 @@ void cTurtleBoss :: Handle_Collision_Massive( cObjectCollision *collision )
 			if( collision->type == CO_ACTIVE )
 			{
 				// get colliding object
-				cSprite *col_object = pLevel->pSprite_Manager->Get_Pointer( collision->number );
+				cSprite *col_object = pActive_Sprite_Manager->Get_Pointer( collision->number );
 
 				if( col_object->type == TYPE_BONUSBOX || col_object->type == TYPE_SPINBOX )
 				{
@@ -1039,62 +1039,79 @@ void cTurtleBoss :: Handle_Collision_Massive( cObjectCollision *collision )
 
 void cTurtleBoss :: Editor_Activate( void )
 {
-	WindowManager &wmgr = WindowManager::getSingleton();
+	CEGUI::WindowManager &wmgr = CEGUI::WindowManager::getSingleton();
+
+	// direction
+	CEGUI::Combobox *combobox = static_cast<CEGUI::Combobox *>(wmgr.createWindow( "TaharezLook/Combobox", "editor_turtle_boss_direction" ));
+	Editor_Add( UTF8_("Direction"), UTF8_("Direction"), combobox, 100, 75 );
+
+	combobox->addItem( new CEGUI::ListboxTextItem( "left" ) );
+	combobox->addItem( new CEGUI::ListboxTextItem( "right" ) );
+
+	combobox->setText( Get_Direction_Name( start_direction ) );
+	combobox->subscribeEvent( CEGUI::Combobox::EventListSelectionAccepted, CEGUI::Event::Subscriber( &cTurtleBoss::Editor_Direction_Select, this ) );
 
 	// max hits
-	Editbox *editbox = (Editbox *)wmgr.createWindow( "TaharezLook/Editbox", "editor_turtle_boss_max_hits" );
+	CEGUI::Editbox *editbox = static_cast<CEGUI::Editbox *>(wmgr.createWindow( "TaharezLook/Editbox", "editor_turtle_boss_max_hits" ));
+	Editor_Add( UTF8_("Hits"), UTF8_("Hits until a downgrade"), editbox, 120 );
 
-	Editor_Add( editbox, 120 );
-	editbox->setTooltipText( "Max Hits" );
 	editbox->setText( int_to_string( max_hits ) );
-	editbox->subscribeEvent( Editbox::EventTextChanged, Event::Subscriber( &cTurtleBoss::Editor_Max_Hits_Key, this ) );
+	editbox->subscribeEvent( CEGUI::Editbox::EventTextChanged, CEGUI::Event::Subscriber( &cTurtleBoss::Editor_Max_Hits_Key, this ) );
 
 	// max downgrades
-	editbox = (Editbox *)wmgr.createWindow( "TaharezLook/Editbox", "editor_turtle_boss_max_downgrade_count" );
-	editbox->setTooltipText( "Max Downgrades" );
-	Editor_Add( editbox, 120 );
+	editbox = static_cast<CEGUI::Editbox *>(wmgr.createWindow( "TaharezLook/Editbox", "editor_turtle_boss_max_downgrade_count" ));
+	Editor_Add( UTF8_("Downgrades"), UTF8_("Downgrades until death"), editbox, 120 );
 
 	editbox->setText( int_to_string( max_downgrade_counts ) );
-	editbox->subscribeEvent( Editbox::EventTextChanged, Event::Subscriber( &cTurtleBoss::Editor_Max_Downgrade_Counts_Key, this ) );
+	editbox->subscribeEvent( CEGUI::Editbox::EventTextChanged, CEGUI::Event::Subscriber( &cTurtleBoss::Editor_Max_Downgrade_Counts_Key, this ) );
 
-	// max downgrade time
-	editbox = (Editbox *)wmgr.createWindow( "TaharezLook/Editbox", "editor_turtle_boss_max_downgrade_time" );
-	editbox->setTooltipText( "Max Downgrade Time" );
-	Editor_Add( editbox, 200 );
+	// max shell time
+	editbox = static_cast<CEGUI::Editbox *>(wmgr.createWindow( "TaharezLook/Editbox", "editor_turtle_boss_max_shell_time" ));
+	Editor_Add( UTF8_("Shell Time"), UTF8_("Time running as shell to rise again"), editbox, 200 );
 
-	editbox->setText( float_to_string( max_downgrade_time ) );
-	editbox->subscribeEvent( Editbox::EventTextChanged, Event::Subscriber( &cTurtleBoss::Editor_Max_Downgrade_Time_Key, this ) );
+	editbox->setText( float_to_string( shell_time ) );
+	editbox->subscribeEvent( CEGUI::Editbox::EventTextChanged, CEGUI::Event::Subscriber( &cTurtleBoss::Editor_Shell_Time_Key, this ) );
 
-	// set position
-	Editor_pos_update();
+	// init
+	Editor_Init();
 }
 
-bool cTurtleBoss :: Editor_Max_Hits_Key( const EventArgs &event )
+bool cTurtleBoss :: Editor_Direction_Select( const CEGUI::EventArgs &event )
 {
-	const WindowEventArgs &windowEventArgs = static_cast<const WindowEventArgs&>( event );
-	string str_text = static_cast<Editbox *>( windowEventArgs.window )->getText().c_str();
+	const CEGUI::WindowEventArgs &windowEventArgs = static_cast<const CEGUI::WindowEventArgs&>( event );
+	CEGUI::ListboxItem *item = static_cast<CEGUI::Combobox *>( windowEventArgs.window )->getSelectedItem();
+
+	Set_Direction( Get_Direction_Id( item->getText().c_str() ), 1 );
+
+	return 1;
+}
+
+bool cTurtleBoss :: Editor_Max_Hits_Key( const CEGUI::EventArgs &event )
+{
+	const CEGUI::WindowEventArgs &windowEventArgs = static_cast<const CEGUI::WindowEventArgs&>( event );
+	string str_text = static_cast<CEGUI::Editbox *>( windowEventArgs.window )->getText().c_str();
 
 	Set_Max_Hits( string_to_int( str_text ) );
 
 	return 1;
 }
 
-bool cTurtleBoss :: Editor_Max_Downgrade_Counts_Key( const EventArgs &event )
+bool cTurtleBoss :: Editor_Max_Downgrade_Counts_Key( const CEGUI::EventArgs &event )
 {
-	const WindowEventArgs &windowEventArgs = static_cast<const WindowEventArgs&>( event );
-	string str_text = static_cast<Editbox *>( windowEventArgs.window )->getText().c_str();
+	const CEGUI::WindowEventArgs &windowEventArgs = static_cast<const CEGUI::WindowEventArgs&>( event );
+	string str_text = static_cast<CEGUI::Editbox *>( windowEventArgs.window )->getText().c_str();
 
 	Set_Max_Downgrade_Counts( string_to_int( str_text ) );
 
 	return 1;
 }
 
-bool cTurtleBoss :: Editor_Max_Downgrade_Time_Key( const EventArgs &event )
+bool cTurtleBoss :: Editor_Shell_Time_Key( const CEGUI::EventArgs &event )
 {
-	const WindowEventArgs &windowEventArgs = static_cast<const WindowEventArgs&>( event );
-	string str_text = static_cast<Editbox *>( windowEventArgs.window )->getText().c_str();
+	const CEGUI::WindowEventArgs &windowEventArgs = static_cast<const CEGUI::WindowEventArgs&>( event );
+	string str_text = static_cast<CEGUI::Editbox *>( windowEventArgs.window )->getText().c_str();
 
-	Set_Max_Downgrade_Time( string_to_float( str_text ) );
+	Set_Shell_Time( string_to_float( str_text ) );
 
 	return 1;
 }
@@ -1114,9 +1131,9 @@ void cTurtleBoss :: Activate_Turtle( void )
 	}
 
 	Update_Direction();
-	Update_Rotation_velx();
+	Update_Rotation_Hor_velx();
 
-	pAudio->PlaySound( "enemy/boss/turtle/power_up.ogg" );
+	pAudio->Play_Sound( "enemy/boss/turtle/power_up.ogg" );
 
 	if( curr_img != 4 )
 	{
@@ -1128,6 +1145,6 @@ void cTurtleBoss :: Activate_Turtle( void )
 
 void cTurtleBoss :: Create_Name( void )
 {
-	name = "TurtleBoss";
-	name += " " + Get_Direction_name( start_direction );
+	name = _("Turtle Boss");
+	name += " " + Get_Direction_Name( start_direction );
 }
