@@ -1,7 +1,7 @@
 /***************************************************************************
-              eato.h  -  headers for the corresponding cpp file
-                             -------------------
-    copyright            : (C) 2006 - 2007 by Florian Richter
+ * eato.h  -  headers for the corresponding cpp file
+ *
+ * Copyright (C) 2006 - 2008 Florian Richter
  ***************************************************************************/
 /*
    This program is free software; you can redistribute it and/or modify
@@ -13,8 +13,8 @@
    along with this program.  If not, see <http://www.gnu.org/licenses/>.
 */
 
-#ifndef __EATO_H__
-#define __EATO_H__
+#ifndef SMC_EATO_H
+#define SMC_EATO_H
 
 #include "../enemies/enemy.h"
 
@@ -29,7 +29,7 @@ public:
 	// constructor
 	cEato( float x, float y );
 	// create from stream
-	cEato( XMLAttributes &attributes );
+	cEato( CEGUI::XMLAttributes &attributes );
 	// destructor
 	virtual ~cEato( void );
 
@@ -39,10 +39,12 @@ public:
 	virtual cEato *Copy( void );
 
 	// create from stream
-	virtual void Create_from_Stream( XMLAttributes &attributes );
+	virtual void Create_from_Stream( CEGUI::XMLAttributes &attributes );
 	// save to stream
 	virtual void Save_to_Stream( ofstream &file );
 
+	// Set the image directory
+	void Set_Image_Dir( string filename );
 	// Set direction
 	void Set_Direction( ObjectDirection dir );
 
@@ -56,10 +58,8 @@ public:
 	virtual void Update( void );
 
 	// if update is valid for the current state
-	virtual bool is_Update_valid( void );
+	virtual bool Is_Update_Valid( void );
 
-	// ignore onground check
-	virtual void Check_onGround( void ) {};
 	/* Validate the given collision object
 	 * returns 1 if an internal collision with this object is valid
 	 * returns 2 if the given object collides with this object (blocking)
@@ -67,6 +67,20 @@ public:
 	virtual unsigned int Validate_Collision( cSprite *obj );
 	// collision from player
 	virtual void Handle_Collision_Player( cObjectCollision *collision );
+
+	// editor activation
+	virtual void Editor_Activate( void );
+	// editor direction option selected event
+	bool Editor_Direction_Select( const CEGUI::EventArgs &event );
+	// editor image dir key up event
+	bool Editor_Image_Dir_Key( const CEGUI::EventArgs &event );
+
+	// image directory
+	string img_dir;
+
+private:
+	// Create the Name from the current settings
+    void Create_Name( void );
 };
 
 /* *** *** *** *** *** *** *** *** *** *** *** *** *** *** *** *** *** */
