@@ -1,7 +1,7 @@
 /***************************************************************************
-              gee.h  -  headers for the corresponding cpp file
-                             -------------------
-    copyright            : (C) 2006 - 2007 by Florian Richter
+ * gee.h  -  headers for the corresponding cpp file
+ *
+ * Copyright (C) 2006 - 2008 Florian Richter
  ***************************************************************************/
 /*
    This program is free software; you can redistribute it and/or modify
@@ -13,8 +13,8 @@
    along with this program.  If not, see <http://www.gnu.org/licenses/>.
 */
 
-#ifndef __GEE_H__
-#define __GEE_H__
+#ifndef SMC_GEE_H
+#define SMC_GEE_H
 
 #include "../enemies/enemy.h"
 
@@ -29,7 +29,7 @@ public:
 	// constructor
 	cGee( float x, float y );
 	// create from stream
-	cGee( XMLAttributes &attributes );
+	cGee( CEGUI::XMLAttributes &attributes );
 	// destructor
 	virtual ~cGee( void );
 
@@ -39,7 +39,7 @@ public:
 	virtual cGee *Copy( void );
 
 	// create from stream
-	virtual void Create_from_Stream( XMLAttributes &attributes );
+	virtual void Create_from_Stream( CEGUI::XMLAttributes &attributes );
 	// save to stream
 	virtual void Save_to_Stream( ofstream &file );
 
@@ -72,13 +72,13 @@ public:
 	// generate small cloud particles ( for moving )
 	void Generate_Particles( void );
 
-	// ignore onground check
-	virtual void Check_onGround( void ) {};
 	// Check if out of max distance
 	bool Check_Max_Distance( void );
 
 	// if update is valid for the current state
-	virtual bool is_Update_valid( void );
+	virtual bool Is_Update_Valid( void );
+	// if draw is valid for the current state and position
+	virtual bool Is_Draw_Valid( void );
 
 	/* Validate the given collision object
 	 * returns 1 if an internal collision with this object is valid
@@ -87,14 +87,21 @@ public:
 	virtual unsigned int Validate_Collision( cSprite *obj );
 	// collision from player
 	virtual void Handle_Collision_Player( cObjectCollision *collision );
+	// collision with massive
+	virtual void Handle_Collision_Massive( cObjectCollision *collision );
 
-	// leveleditor activation
+	// editor activation
 	virtual void Editor_Activate( void );
-	// leveleditor events
-	bool Editor_Max_Distance_Key( const EventArgs &event );  // editor max distance key up
-	bool Editor_Always_Fly_Select( const EventArgs &event ); // editor always fly option selected
-	bool Editor_Wait_Time_Key( const EventArgs &event );  // editor wait time key up
-	bool Editor_Fly_Distance_Key( const EventArgs &event );  // editor fly distance key up
+	// editor direction option selected event
+	bool Editor_Direction_Select( const CEGUI::EventArgs &event );
+	// editor max distance key up event
+	bool Editor_Max_Distance_Key( const CEGUI::EventArgs &event );
+	// editor always fly option selected event
+	bool Editor_Always_Fly_Select( const CEGUI::EventArgs &event );
+	// editor wait time key up event
+	bool Editor_Wait_Time_Key( const CEGUI::EventArgs &event );
+	// editor fly distance key up event
+	bool Editor_Fly_Distance_Key( const CEGUI::EventArgs &event );
 
 	// color
 	DefaultColor color_type;
@@ -120,7 +127,6 @@ public:
 private:
 	// Create the Name from the current settings
     void Create_Name( void );
-
 };
 
 /* *** *** *** *** *** *** *** *** *** *** *** *** *** *** *** *** *** */
