@@ -1,7 +1,7 @@
 /***************************************************************************
-              jpiranha.cpp  -  jumping piranha plant
-                             -------------------
-    copyright            : (C) 2003 - 2007 by Florian Richter
+ * jpiranha.cpp  -  jumping piranha plant
+ *
+ * Copyright (C) 2003 - 2008 Florian Richter
  ***************************************************************************/
 /*
    This program is free software; you can redistribute it and/or modify
@@ -20,20 +20,27 @@
 #include "../core/obj_manager.h"
 #include "../video/animation.h"
 #include "../user/savegame.h"
+#include "../core/math/utilities.h"
+#include "../input/mouse.h"
+#include "../video/gl_surface.h"
+#include "../core/i18n.h"
+// boost filesystem
+#include "boost/filesystem/convenience.hpp"
+namespace fs = boost::filesystem;
 
 /* *** *** *** *** *** *** cjPiranha *** *** *** *** *** *** *** *** *** *** *** */
 
 cjPiranha :: cjPiranha( float x, float y )
 : cEnemy( x, y )
 {
-	Init();
+	cjPiranha::Init();
 }
 
-cjPiranha :: cjPiranha( XMLAttributes &attributes )
+cjPiranha :: cjPiranha( CEGUI::XMLAttributes &attributes )
 : cEnemy()
 {
-	Init();
-	Create_from_Stream( attributes );
+	cjPiranha::Init();
+	cjPiranha::Create_from_Stream( attributes );
 }
 
 cjPiranha :: ~cjPiranha( void )
@@ -45,19 +52,23 @@ void cjPiranha :: Init( void  )
 {
 	type = TYPE_JPIRANHA;
 	posz = 0.06f;
+	Set_Rotation_affects_Rect( 1 );
 	editor_posz = 0.089f;
 	player_range = 1000;
+	can_be_on_ground = 0;
+	can_be_ground = 0;
 
 	state = STA_STAY;
 	Set_Direction( DIR_UP );
+	Set_Image_Dir( "enemy/jpiranha/orange/" );
 	Set_Max_Distance( 200 );
 	Set_Speed( 5.8f );
 
 	kill_sound = "enemy/jpiranha/die.ogg";
 	kill_points = 100;
 
-	walk_count = static_cast<float>( rand() % 4 );
-	wait_time = static_cast<float>( rand() % 70 );
+	walk_count = Get_Random_Float( 0, 4 );
+	wait_time = Get_Random_Float( 0, 70 );
 	move_back = 0;
 }
 
@@ -65,17 +76,20 @@ cjPiranha *cjPiranha :: Copy( void )
 {
 	cjPiranha *jpiranha = new cjPiranha( startposx, startposy );
 	jpiranha->Set_Direction( start_direction );
+	jpiranha->Set_Image_Dir( img_dir );
 	jpiranha->Set_Max_Distance( max_distance );
 	jpiranha->Set_Speed( speed );
 	return jpiranha;
 }
 
-void cjPiranha :: Create_from_Stream( XMLAttributes &attributes )
+void cjPiranha :: Create_from_Stream( CEGUI::XMLAttributes &attributes )
 {
 	// position
 	Set_Pos( static_cast<float>(attributes.getValueAsInteger( "posx" )), static_cast<float>(attributes.getValueAsInteger( "posy" )), 1 );
 	// direction
-	Set_Direction( Get_Direction_id( attributes.getValueAsString( "direction", Get_Direction_name( start_direction ) ).c_str() ) );
+	Set_Direction( Get_Direction_Id( attributes.getValueAsString( "direction", Get_Direction_Name( start_direction ) ).c_str() ) );
+	// image directory
+	Set_Image_Dir( attributes.getValueAsString( "image_dir", img_dir ).c_str() );
 	// max distance
 	Set_Max_Distance( attributes.getValueAsFloat( "max_distance", max_distance ) );
 	// speed
@@ -93,7 +107,9 @@ void cjPiranha :: Save_to_Stream( ofstream &file )
 	file << "\t\t<Property name=\"posx\" value=\"" << static_cast<int>(startposx) << "\" />" << std::endl;
 	file << "\t\t<Property name=\"posy\" value=\"" << static_cast<int>(startposy) << "\" />" << std::endl;
 	// direction
-	file << "\t\t<Property name=\"direction\" value=\"" << Get_Direction_name( start_direction ) << "\" />" << std::endl;
+	file << "\t\t<Property name=\"direction\" value=\"" << Get_Direction_Name( start_direction ) << "\" />" << std::endl;
+	// image directory
+	file << "\t\t<Property name=\"image_dir\" value=\"" << img_dir << "\" />" << std::endl;
 	// max distance
 	file << "\t\t<Property name=\"max_distance\" value=\"" << static_cast<int>(max_distance) << "\" />" << std::endl;
 	// speed
@@ -127,57 +143,77 @@ cSave_Level_Object *cjPiranha :: Save_to_Savegame( void )
 	return save_object;
 }
 
-void cjPiranha :: Set_Direction( ObjectDirection dir )
+void cjPiranha :: Set_Image_Dir( string dir )
 {
-	// already set
-	if( direction == dir )
+	if( dir.empty() )
 	{
 		return;
 	}
 
-	// clear old images
+	// remove pixmaps dir
+	if( img_dir.find( DATA_DIR "/" GAME_PIXMAPS_DIR "/" ) == 0 )
+	{
+		img_dir.erase( 0, strlen( DATA_DIR "/" GAME_PIXMAPS_DIR "/" ) );
+	}
+
+	// if directory does not exist
+	if( !fs::exists( fs::path( DATA_DIR "/" GAME_PIXMAPS_DIR "/" + dir, fs::native ) ) )
+	{
+		return;
+	}
+
+	img_dir = dir;
+
+	// clear images
 	Clear_Images();
+	// set images
+	images.push_back( pVideo->Get_Surface( img_dir + "closed_1.png" ) );
+	images.push_back( pVideo->Get_Surface( img_dir + "closed_2.png" ) );
+	images.push_back( pVideo->Get_Surface( img_dir + "open_1.png" ) );
+	images.push_back( pVideo->Get_Surface( img_dir + "open_2.png" ) );
+	// set start image
+	Set_Image( 0, 1 );
 
-	cEnemy::Set_Direction( dir, 1 );
+	Create_Name();
+}
 
-	string filename_dir;
-	name = "jPiranha";
+void cjPiranha :: Set_Direction( ObjectDirection dir )
+{
+	// already set
+	if( dir == direction )
+	{
+		return;
+	}
 
-	if( direction == DIR_UP )
+	if( dir != DIR_UP && dir != DIR_DOWN && dir != DIR_LEFT && dir != DIR_RIGHT )
 	{
-		filename_dir = "up";
-		name += " Up";
-	}
-	else if( direction == DIR_DOWN )
-	{
-		filename_dir = "down";
-		name += " Down";
-	}
-	else if( direction == DIR_LEFT )
-	{
-		filename_dir = "left";
-		name += " Left";
-	}
-	else if( direction == DIR_RIGHT )
-	{
-		filename_dir = "right";
-		name += " Right";
-	}
-	else
-	{
-		Set_Dead( 1 );
-		Set_Visible( 0 );
-
 		printf( "Error : Unknown jPiranha direction %d\n", direction );
 		return;
 	}
 
-	images.push_back( pVideo->Get_Surface( "enemy/jpiranha/" + filename_dir + "_closed_1.png" ) );
-	images.push_back( pVideo->Get_Surface( "enemy/jpiranha/" + filename_dir + "_closed_2.png" ) );
-	images.push_back( pVideo->Get_Surface( "enemy/jpiranha/" + filename_dir + "_open_1.png" ) );
-	images.push_back( pVideo->Get_Surface( "enemy/jpiranha/" + filename_dir + "_open_2.png" ) );
+	cEnemy::Set_Direction( dir, 1 );
 
-	Set_Image( 0, 1 );
+	// clear
+	Set_Rotation( 0, 0, 0, 1 );
+
+	if( start_direction == DIR_UP )
+	{
+		// default
+	}
+	else if( start_direction == DIR_LEFT )
+	{
+		Set_Rotation_Z( 270, 1 );
+	}
+	else if( start_direction == DIR_RIGHT )
+	{
+		Set_Rotation_Z( 90, 1 );
+	}
+	else if( start_direction == DIR_DOWN )
+	{
+		Set_Rotation_Z( 180, 1 );
+	}
+
+	Create_Name();
 }
 
 void cjPiranha :: Set_Max_Distance( float nmax_distance )
@@ -199,7 +235,7 @@ void cjPiranha :: Set_Speed( float val )
 
 	speed = val;
 
-	Update_dest_vel();
+	Update_Dest_Vel();
 }
 
 void cjPiranha :: DownGrade( bool force /* = 0 */ )
@@ -213,17 +249,18 @@ void cjPiranha :: DownGrade( bool force /* = 0 */ )
 	if( !force )
 	{
 		// animation
-		cParticleAnimation *anim = new cParticleAnimation( posx + ( col_rect.w / 2 ), posy + ( col_rect.h / 2 ) );
+		cParticle_Emitter *anim = new cParticle_Emitter();
+		anim->Set_Pos( posx + ( col_rect.w / 2 ), posy + ( col_rect.h / 2 ) );
 		Generate_Hit_Animation( anim );
 
 		anim->Set_Speed( 5, 0.6f );
 		anim->Set_Scale( 0.8f );
 		// add animation
-		pAnimationManager->Add( anim );
+		pAnimation_Manager->Add( anim );
 	}
 	else
 	{
-		Set_RotationZ( 180 );
+		Set_Rotation_Z( 180 );
 	}
 }
 
@@ -245,7 +282,7 @@ void cjPiranha :: DieStep( void )
 			Move( 0, -5 );
 		}
 		// if not below the screen fall
-		else if( posy < GAME_RES_H + col_rect.h )
+		else if( posy < game_res_h + col_rect.h )
 		{
 			Move( 0, 20 );
 		}
@@ -309,7 +346,7 @@ void cjPiranha :: Update( void )
 			// if player is in front wait again
 			if( pPlayer->maryo_type != MARYO_GHOST && Col_Box( &pPlayer->col_rect, &rect1 ) )
 			{
-				wait_time = DESIRED_FPS * 2;
+				wait_time = speedfactor_fps * 2;
 			}
 			// if not jump out
 			else
@@ -353,6 +390,7 @@ void cjPiranha :: Update( void )
 			{
 				velx = -dest_velx * vel_mod_min;
 			}
+			break;
 		}
 		case DIR_RIGHT:
 		{
@@ -366,6 +404,7 @@ void cjPiranha :: Update( void )
 			{
 				velx = -dest_velx * vel_mod_min;
 			}
+			break;
 		}
 		case DIR_UP:
 		{
@@ -379,6 +418,7 @@ void cjPiranha :: Update( void )
 			{
 				vely = -dest_vely * vel_mod_min;
 			}
+			break;
 		}
 		case DIR_DOWN:
 		{
@@ -392,6 +432,7 @@ void cjPiranha :: Update( void )
 			{
 				vely = -dest_vely * vel_mod_min;
 			}
+			break;
 		}
 		default:
 		{
@@ -433,7 +474,7 @@ void cjPiranha :: Update( void )
 				vely = 0;
 
 				move_back = 0;
-				wait_time = DESIRED_FPS * 2;
+				wait_time = speedfactor_fps * 2;
 				Set_Image( 0 );
 			}
 		}
@@ -452,19 +493,19 @@ void cjPiranha :: Draw( cSurfaceRequest *request /* = NULL */ )
 	{
 		if( start_direction == DIR_RIGHT )
 		{
-			pVideo->Draw_Rect( startposx - pCamera->x, startposy + ( rect.h * 0.5f ) - 5 - pCamera->y, max_distance + rect.w, 10, editor_posz - 0.000001f, &whitealpha128 );
+			pVideo->Draw_Rect( startposx - pActive_Camera->x, startposy + ( rect.h * 0.5f ) - 5 - pActive_Camera->y, max_distance + rect.w, 10, editor_posz - 0.000001f, &whitealpha128 );
 		}
 		else if( start_direction == DIR_LEFT )
 		{
-			pVideo->Draw_Rect( startposx - pCamera->x + rect.w, startposy + ( rect.h * 0.5f ) - 5 - pCamera->y, -( rect.w + max_distance ), 10, editor_posz - 0.000001f, &whitealpha128 );
+			pVideo->Draw_Rect( startposx - pActive_Camera->x + rect.w, startposy + ( rect.h * 0.5f ) - 5 - pActive_Camera->y, -( rect.w + max_distance ), 10, editor_posz - 0.000001f, &whitealpha128 );
 		}
 		else if( start_direction == DIR_DOWN )
 		{
-			pVideo->Draw_Rect( startposx + ( rect.w * 0.5f ) - 5 - pCamera->x, startposy - pCamera->y, 10, max_distance + rect.h, editor_posz - 0.000001f, &whitealpha128 );
+			pVideo->Draw_Rect( startposx + ( rect.w * 0.5f ) - 5 - pActive_Camera->x, startposy - pActive_Camera->y, 10, max_distance + rect.h, editor_posz - 0.000001f, &whitealpha128 );
 		}
 		else if( start_direction == DIR_UP )
 		{
-			pVideo->Draw_Rect( startposx + ( rect.w * 0.5f ) - 5 - pCamera->x, startposy - pCamera->y + rect.h, 10, -( rect.h + max_distance ), editor_posz - 0.000001f, &whitealpha128 );
+			pVideo->Draw_Rect( startposx + ( rect.w * 0.5f ) - 5 - pActive_Camera->x, startposy - pActive_Camera->y + rect.h, 10, -( rect.h + max_distance ), editor_posz - 0.000001f, &whitealpha128 );
 		}
 	}
 
@@ -500,7 +541,7 @@ float cjPiranha :: Get_End_Distance(void )
 	return 0;
 }
 
-void cjPiranha :: Update_dest_vel( void )
+void cjPiranha :: Update_Dest_Vel( void )
 {
 	if( direction == DIR_UP )
 	{
@@ -529,7 +570,7 @@ void cjPiranha :: Update_dest_vel( void )
 	}
 }
 
-bool cjPiranha :: is_Update_valid( void )
+bool cjPiranha :: Is_Update_Valid( void )
 {
 	if( dead || freeze_counter )
 	{
@@ -539,6 +580,24 @@ bool cjPiranha :: is_Update_valid( void )
 	return 1;
 }
 
+bool cjPiranha :: Is_Draw_Valid( void )
+{
+	bool valid = cEnemy::Is_Draw_Valid();
+
+	// if editor enabled
+	if( editor_enabled )
+	{
+		// if active mouse object
+		if( pMouseCursor->active_object == this )
+		{
+			return 1;
+		}
+	}
+
+
+	return valid;
+}
+
 unsigned int cjPiranha :: Validate_Collision( cSprite *obj )
 {
 	if( obj->type == TYPE_PLAYER )
@@ -565,52 +624,100 @@ void cjPiranha :: Handle_Collision_Player( cObjectCollision *collision )
 	{
 		// todo : create again
 		//pAudio->PlaySound( "player/maryo_au.ogg", RID_MARYO_AU );
-		pPlayer->start_enemyjump = 1;
+		pPlayer->Action_Jump( 1 );
 	}
 
-	pPlayer->DownGrade();
+	pPlayer->DownGrade_Player();
 }
 
 void cjPiranha :: Editor_Activate( void )
 {
-	WindowManager &wmgr = WindowManager::getSingleton();
+	CEGUI::WindowManager &wmgr = CEGUI::WindowManager::getSingleton();
+
+	// direction
+	CEGUI::Combobox *combobox = static_cast<CEGUI::Combobox *>(wmgr.createWindow( "TaharezLook/Combobox", "editor_jpiranha_direction" ));
+	Editor_Add( UTF8_("Direction"), UTF8_("Direction"), combobox, 100, 110 );
+
+	combobox->addItem( new CEGUI::ListboxTextItem( "up" ) );
+	combobox->addItem( new CEGUI::ListboxTextItem( "down" ) );
+	combobox->addItem( new CEGUI::ListboxTextItem( "left" ) );
+	combobox->addItem( new CEGUI::ListboxTextItem( "right" ) );
+
+	combobox->setText( Get_Direction_Name( start_direction ) );
+	combobox->subscribeEvent( CEGUI::Combobox::EventListSelectionAccepted, CEGUI::Event::Subscriber( &cjPiranha::Editor_Direction_Select, this ) );
+
+	// image dir
+	CEGUI::Editbox *editbox = static_cast<CEGUI::Editbox *>(wmgr.createWindow( "TaharezLook/Editbox", "editor_jpiranha_image_dir" ));
+	Editor_Add( UTF8_("Image directory"), UTF8_("Directory containing the images"), editbox, 200 );
+
+	editbox->setText( img_dir.c_str() );
+	editbox->subscribeEvent( CEGUI::Editbox::EventTextChanged, CEGUI::Event::Subscriber( &cjPiranha::Editor_Image_Dir_Key, this ) );
 
 	// max distance
-	Editbox *editbox = static_cast<Editbox *>(wmgr.createWindow( "TaharezLook/Editbox", "editor_jpiranha_max_distance" ));
-	editbox->setTooltipText( "Max Distance" );
-	Editor_Add( editbox, 90 );
+	editbox = static_cast<CEGUI::Editbox *>(wmgr.createWindow( "TaharezLook/Editbox", "editor_jpiranha_max_distance" ));
+	Editor_Add( UTF8_("Distance"), _("Movable Distance into its direction"), editbox, 90 );
 
 	editbox->setText( int_to_string( static_cast<int>(max_distance) ) );
-	editbox->subscribeEvent( Editbox::EventKeyUp, Event::Subscriber( &cjPiranha::Editor_Max_Distance_Key, this ) );
+	editbox->subscribeEvent( CEGUI::Editbox::EventKeyUp, CEGUI::Event::Subscriber( &cjPiranha::Editor_Max_Distance_Key, this ) );
 
 	// speed
-	editbox = static_cast<Editbox *>(wmgr.createWindow( "TaharezLook/Editbox", "editor_jpiranha_speed" ));
-	editbox->setTooltipText( "Speed" );
-	Editor_Add( editbox, 120 );
+	editbox = static_cast<CEGUI::Editbox *>(wmgr.createWindow( "TaharezLook/Editbox", "editor_jpiranha_speed" ));
+	Editor_Add( UTF8_("Speed"), UTF8_("Initial speed when jumping out"), editbox, 120 );
 
 	editbox->setText( float_to_string( speed ) );
-	editbox->subscribeEvent( Editbox::EventKeyUp, Event::Subscriber( &cjPiranha::Editor_Speed_Key, this ) );
+	editbox->subscribeEvent( CEGUI::Editbox::EventKeyUp, CEGUI::Event::Subscriber( &cjPiranha::Editor_Speed_Key, this ) );
 
-	// set position
-	Editor_pos_update();
+	// init
+	Editor_Init();
 }
 
-bool cjPiranha :: Editor_Max_Distance_Key( const EventArgs &event )
+bool cjPiranha :: Editor_Direction_Select( const CEGUI::EventArgs &event )
 {
-	const WindowEventArgs &windowEventArgs = static_cast<const WindowEventArgs&>( event );
-	string str_text = static_cast<Editbox *>( windowEventArgs.window )->getText().c_str();
+	const CEGUI::WindowEventArgs &windowEventArgs = static_cast<const CEGUI::WindowEventArgs&>( event );
+	CEGUI::ListboxItem *item = static_cast<CEGUI::Combobox *>( windowEventArgs.window )->getSelectedItem();
+
+	Set_Direction( Get_Direction_Id( item->getText().c_str() ) );
+
+	return 1;
+}
+
+bool cjPiranha :: Editor_Image_Dir_Key( const CEGUI::EventArgs &event )
+{
+	const CEGUI::WindowEventArgs &windowEventArgs = static_cast<const CEGUI::WindowEventArgs&>( event );
+	string str_text = static_cast<CEGUI::Editbox *>( windowEventArgs.window )->getText().c_str();
+
+	Set_Image_Dir( str_text );
+
+	return 1;
+}
+
+bool cjPiranha :: Editor_Max_Distance_Key( const CEGUI::EventArgs &event )
+{
+	const CEGUI::WindowEventArgs &windowEventArgs = static_cast<const CEGUI::WindowEventArgs&>( event );
+	string str_text = static_cast<CEGUI::Editbox *>( windowEventArgs.window )->getText().c_str();
 
 	Set_Max_Distance( static_cast<float>(string_to_int( str_text )) );
 
 	return 1;
 }
 
-bool cjPiranha :: Editor_Speed_Key( const EventArgs &event )
+bool cjPiranha :: Editor_Speed_Key( const CEGUI::EventArgs &event )
 {
-	const WindowEventArgs &windowEventArgs = static_cast<const WindowEventArgs&>( event );
-	string str_text = static_cast<Editbox *>( windowEventArgs.window )->getText().c_str();
+	const CEGUI::WindowEventArgs &windowEventArgs = static_cast<const CEGUI::WindowEventArgs&>( event );
+	string str_text = static_cast<CEGUI::Editbox *>( windowEventArgs.window )->getText().c_str();
 
 	Set_Speed( string_to_float( str_text ) );
 
 	return 1;
 }
+
+void cjPiranha :: Create_Name( void )
+{
+	name = "jPiranha ";
+	name += _(Get_Direction_Name( start_direction ).c_str());
+
+	if( start_image && !start_image->name.empty() )
+	{
+		name += " " + start_image->name;
+	}
+}
