@@ -1,7 +1,7 @@
 /***************************************************************************
-                spika.h  -  headers for the corresponding cpp file
-                             -------------------
-    copyright            :	(C) 2006 - 2007 Florian Richter
+ * spika.h  -  headers for the corresponding cpp file
+ *
+ * Copyright (C) 2006 - 2008 Florian Richter
  ***************************************************************************/
 /*
    This program is free software; you can redistribute it and/or modify
@@ -13,8 +13,8 @@
    along with this program.  If not, see <http://www.gnu.org/licenses/>.
 */
 
-#ifndef __SPIKA_H__
-#define __SPIKA_H__
+#ifndef SMC_SPIKA_H
+#define SMC_SPIKA_H
 
 #include "../enemies/enemy.h"
 
@@ -32,7 +32,7 @@ public:
 	// constructor
 	cSpika( float x, float y );
 	// create from stream
-	cSpika( XMLAttributes &attributes );
+	cSpika( CEGUI::XMLAttributes &attributes );
 	// destructor
 	virtual ~cSpika( void );
 
@@ -42,7 +42,7 @@ public:
 	virtual cSpika *Copy( void );
 
 	// create from stream
-	virtual void Create_from_Stream( XMLAttributes &attributes );
+	virtual void Create_from_Stream( CEGUI::XMLAttributes &attributes );
 	// save to stream
 	virtual void Save_to_Stream( ofstream &file );
 
@@ -59,7 +59,7 @@ public:
 	virtual void Update( void );
 
 	// if update is valid for the current state
-	virtual bool is_Update_valid( void );
+	virtual bool Is_Update_Valid( void );
 
 	/* Validate the given collision object
 	 * returns 1 if an internal collision with this object is valid
