@@ -1,7 +1,7 @@
 /***************************************************************************
-                static.h  -  headers for the corresponding cpp file
-                             -------------------
-    copyright            :	(C) 2007 Florian Richter
+ * static.h  -  headers for the corresponding cpp file
+ *
+ * Copyright (C) 2007 - 2008 Florian Richter
  ***************************************************************************/
 /*
    This program is free software; you can redistribute it and/or modify
@@ -13,8 +13,8 @@
    along with this program.  If not, see <http://www.gnu.org/licenses/>.
 */
 
-#ifndef __STATIC_ENEMY_H__
-#define __STATIC_ENEMY_H__
+#ifndef SMC_STATIC_ENEMY_H
+#define SMC_STATIC_ENEMY_H
 
 #include "../enemies/enemy.h"
 
@@ -22,18 +22,14 @@
 
 class cStaticEnemy : public cEnemy 
 {
-/* Static
- * Static Objects don't move but will
+/* Static enemies don't move but will
  * hit you if you touch them.
- * 
- * Todo : Should use Image Super-Class which is not implemented yet ;)
- * and the image should be a setting
  */
 public:
 	// constructor
 	cStaticEnemy( float x, float y );
 	// create from stream
-	cStaticEnemy( XMLAttributes &attributes );
+	cStaticEnemy( CEGUI::XMLAttributes &attributes );
 	// destructor
 	virtual ~cStaticEnemy( void );
 
@@ -43,10 +39,15 @@ public:
 	virtual cStaticEnemy *Copy( void );
 
 	// create from stream
-	virtual void Create_from_Stream( XMLAttributes &attributes );
+	virtual void Create_from_Stream( CEGUI::XMLAttributes &attributes );
 	// save to stream
 	virtual void Save_to_Stream( ofstream &file );
 
+	// Set the static image
+	void Set_Static_Image( string filename );
+	// Set the rotation speed
+	void Set_Rotation_Speed( float speed );
+
 	/* downgrade state ( if already weakest state : dies )
 	 * force : usually dies or a complete downgrade
 	*/
@@ -57,10 +58,8 @@ public:
 	virtual void Update( void );
 
 	// if update is valid for the current state
-	virtual bool is_Update_valid( void );
+	virtual bool Is_Update_Valid( void );
 
-	// ignore onground check
-	virtual void Check_onGround( void ) {};
 	/* Validate the given collision object
 	 * returns 1 if an internal collision with this object is valid
 	 * returns 2 if the given object collides with this object (blocking)
@@ -71,8 +70,20 @@ public:
 	// collision from an enemy
 	virtual void Handle_Collision_Enemy( cObjectCollision *collision );
 
-	// default speed
-	float speed;
+	// leveleditor activation
+	virtual void Editor_Activate( void );
+	// leveleditor events
+	bool Editor_Image_Key( const CEGUI::EventArgs &event );  // editor image key up
+	bool Editor_Rotation_Speed_Key( const CEGUI::EventArgs &event );  // editor rotation speed key up
+
+	// image filename
+	string img_filename;
+	// rotation speed
+	float rotation_speed;
+
+private:
+	// Create the Name from the current settings
+    void Create_Name( void );
 };
 
 /* *** *** *** *** *** *** *** *** *** *** *** *** *** *** *** *** *** */
