@@ -1,7 +1,7 @@
 /***************************************************************************
-                turtle.h  -  headers for the corresponding cpp file
-                             -------------------
-    copyright            :	(C) 2003 - 2007 by Florian Richter
+ * turtle.h  -  headers for the corresponding cpp file
+ *
+ * Copyright (C) 2003 - 2008 Florian Richter
  ***************************************************************************/
 /*
    This program is free software; you can redistribute it and/or modify
@@ -13,8 +13,8 @@
    along with this program.  If not, see <http://www.gnu.org/licenses/>.
 */
 
-#ifndef __TURTLE_H__
-#define __TURTLE_H__
+#ifndef SMC_TURTLE_H
+#define SMC_TURTLE_H
 
 #include "../enemies/enemy.h"
 
@@ -37,7 +37,7 @@ public:
 	// constructor
 	cTurtle( float x, float y );
 	// create from stream
-	cTurtle( XMLAttributes &attributes );
+	cTurtle( CEGUI::XMLAttributes &attributes );
 	// destructor
 	virtual ~cTurtle( void );
 
@@ -47,7 +47,7 @@ public:
 	virtual cTurtle *Copy( void );
 
 	// create from stream
-	virtual void Create_from_Stream( XMLAttributes &attributes );
+	virtual void Create_from_Stream( CEGUI::XMLAttributes &attributes );
 	// save to stream
 	virtual void Save_to_Stream( ofstream &file );
 
@@ -57,7 +57,7 @@ public:
 	virtual cSave_Level_Object *Save_to_Savegame( void );
 
 	// Set Direction
-	void Set_Direction( ObjectDirection dir, bool new_start_direction = 0 );
+	virtual void Set_Direction( ObjectDirection dir, bool new_start_direction = 0 );
 	// set color
 	void Set_Color( DefaultColor col );
 
@@ -76,7 +76,7 @@ public:
 	virtual void Update( void );
 
 	// if update is valid for the current state
-	virtual bool is_Update_valid( void );
+	virtual bool Is_Update_Valid( void );
 
 	/* Validate the given collision object
 	 * returns 1 if an internal collision with this object is valid
@@ -90,6 +90,11 @@ public:
 	// collision with massive
 	virtual void Handle_Collision_Massive( cObjectCollision *collision );
 
+	// editor activation
+	virtual void Editor_Activate( void );
+	// editor direction option selected event
+	bool Editor_Direction_Select( const CEGUI::EventArgs &event );
+
 	// internal turtle state
 	Turtle_state turtle_state;
 
