@@ -1,7 +1,7 @@
 /***************************************************************************
-				menu.cpp  -  nice menu visible at the beginning of the game :)
-                             -------------------
-    copyright            :	(C) 2003 - 2007 by Florian Richter
+ * menu.cpp  -  menu handler
+ *
+ * Copyright (C) 2003 - 2008 Florian Richter
  ***************************************************************************/
 /*
    This program is free software; you can redistribute it and/or modify
@@ -34,6 +34,7 @@
 cMenu_Item :: cMenu_Item( void )
 : cHudSprite()
 {
+	Set_Scale_Directions( 1, 1, 1, 1 );
 	active = 0;
 	isquit = 0;
 
@@ -88,11 +89,6 @@ void cMenu_Item :: Draw( cSurfaceRequest *request /* = NULL */ )
 		{
 			rotz = 0;
 		}
-
-		// todo : sprite scaling should also set the position
-		// set correct position
-		posx -= ( image->w / 2 ) * ( scalex - 1 );
-		posy -= ( image->h / 2 ) * ( scaley - 1 );
 	}
 
 	cHudSprite::Draw( request );
@@ -117,34 +113,112 @@ cMenuHandler :: cMenuHandler( void )
 {
 	Reset();
 
-	image_ground = pVideo->Get_Surface( "menu/ground.png" );
-	image_ground_quit = pVideo->Get_Surface( "menu/ground_quit.png" );
+	// SMC logo image
+	cHudSprite *sprite = new cHudSprite( pVideo->Get_Surface( "game/logo/smc_big_1.png" ), 50, 20 );
+	sprite->posz = 0.16f;
+	images.push_back( sprite );
 
-	// Logo Image
-	logo = new cHudSprite( pVideo->Get_Surface( "game/logo/lmario1.png" ), 50, 20 );
-	logo->posz = 0.16f;
-	// Ground Image
-	ground = new cHudSprite( image_ground, 0, 400 );
-	ground->posz = 0.11f;
-	// Moon Image
-	moon = new cHudSprite( pVideo->Get_Surface( "game/items/moon_1.png" ), 702, 39 );
-	moon->posz = 0.16f;
-	// Cloud Image
-	background = new cHudSprite( pVideo->Get_Surface( "game/background/blue_hills_1.png" ), 0, 88 );
-	background->posz = 0.09f;
+	// moon image
+	sprite = new cHudSprite( pVideo->Get_Surface( "game/items/moon_1.png" ), 702, 39 );
+	sprite->posz = 0.16f;
+	images.push_back( sprite );
+	// background image
+	sprite = new cHudSprite( pVideo->Get_Surface( "game/background/blue_hills_1.png" ), 0, 88 );
+	sprite->posz = 0.09f;
+	images.push_back( sprite );
+
+	// ground images
+	float pos_x = 0;
+	cGL_Surface *image = pVideo->Get_Surface( "ground/green_3/ground/top/left.png" );
+	float ground_width = image->w;
+	float ground_height = image->h;
+	
+	for( int i = 0; i < game_res_w; i += static_cast<int>(ground_width) )
+	{
+		// start with left up image
+		if( i == 0 )
+		{
+			sprite = new cHudSprite( image, pos_x, static_cast<float>(game_res_h) - ground_height );
+		}
+		// change to middle up image
+		else
+		{
+			sprite = new cHudSprite( pVideo->Get_Surface( "ground/green_3/ground/top/1.png" ), pos_x, static_cast<float>(game_res_h) - ground_height );
+		}
+
+		sprite->posz = 0.091f;
+		images.push_back( sprite );
+
+		pos_x += sprite->rect.w;
+	}
+
+	// big hedge image
+	sprite = new cHudSprite( pVideo->Get_Surface( "ground/jungle_1/big_plant_1.png" ), 32, static_cast<float>(game_res_h) - ground_height - 256 );
+	sprite->posz = 0.094f;
+	images.push_back( sprite );
+
+	// medium hedge image
+	sprite = new cHudSprite( pVideo->Get_Surface( "ground/green_1/hedges/medium_2.png" ), 410, static_cast<float>(game_res_h) - ground_height - 43 );
+	sprite->posz = 0.094f;
+	images.push_back( sprite );
+
+	// small hedge image
+	sprite = new cHudSprite( pVideo->Get_Surface( "ground/green_1/hedges/small_1.png" ), 240, static_cast<float>(game_res_h) - ground_height - 43 );
+	sprite->posz = 0.094f;
+	images.push_back( sprite );
+
+	// pipe middle image
+	sprite = new cHudSprite( pVideo->Get_Surface( "pipes/orange/ver.png" ), 620, static_cast<float>(game_res_h) - ground_height - 50 );
+	sprite->posz = 0.094f;
+	images.push_back( sprite );
+
+	// pipe middle image
+	sprite = new cHudSprite( pVideo->Get_Surface( "pipes/orange/ver.png" ), 620, static_cast<float>(game_res_h) - ground_height - 50 - 50 );
+	sprite->posz = 0.094f;
+	images.push_back( sprite );
+
+	// pipe top image
+	sprite = new cHudSprite( pVideo->Get_Surface( "pipes/orange/up.png" ), 620, static_cast<float>(game_res_h) - ground_height - 50 - 50 - 50 );
+	sprite->posz = 0.094f;
+	images.push_back( sprite );
+
+	// jumping piranha orange image
+	sprite = new cHudSprite( pVideo->Get_Surface( "enemy/jpiranha/orange/open_1.png" ), 648, static_cast<float>(game_res_h) - ground_height - 50 - 50 - 50 - 36 );
+	sprite->posz = 0.093f;
+	images.push_back( sprite );
+
+	// very small hedge image
+	sprite = new cHudSprite( pVideo->Get_Surface( "ground/green_2/hedges/small_1.png" ), 710, static_cast<float>(game_res_h) - ground_height - 32 );
+	sprite->posz = 0.094f;
+	images.push_back( sprite );
+
+	// furball blue image
+	sprite = new cHudSprite( pVideo->Get_Surface( "enemy/furball/blue/walk_4.png" ), 360, static_cast<float>(game_res_h) - ground_height - 43 );
+	sprite->posz = 0.095f;
+	images.push_back( sprite );
+
+	// eato brown image
+	sprite = new cHudSprite( pVideo->Get_Surface( "enemy/eato/brown/1.png" ), 100, static_cast<float>(game_res_h) - ground_height - 36 );
+	sprite->posz = 0.095f;
+	images.push_back( sprite );
+
+	// maryo falling image
+	sprite = new cHudSprite( pVideo->Get_Surface( "maryo/small/fall_right.png" ), 100, static_cast<float>(game_res_h) - ground_height - 58 - 90 );
+	sprite->posz = 0.095f;
+	images.push_back( sprite );
 }
 
 cMenuHandler :: ~cMenuHandler( void )
 {
 	Reset();
 
-	delete logo;
-	delete ground;
-	delete moon;
-	delete background;
+	for( HudSpriteList::iterator itr = images.begin(), itr_end = images.end(); itr != itr_end; ++itr )
+	{
+		delete *itr;
+	}
 }
 
-void cMenuHandler :: Add_MenuItem( cMenu_Item *item, float shadow_pos /* = 0 */, Color shadow_color /* = static_cast<Uint8>(0) */ )
+void cMenuHandler :: Add_Menu_Item( cMenu_Item *item, float shadow_pos /* = 0 */, Color shadow_color /* = static_cast<Uint8>(0) */ )
 {
 	if( !item )
 	{
@@ -174,8 +248,6 @@ void cMenuHandler :: Reset( void )
 
 	// nothing is active
 	active = -1;
-	// disable quit logo
-	use_quit_image = 0;
 
 	// Default Gradient Colors
 	color_start = Color( 0.7f, 0.93f, 1 );
@@ -197,15 +269,6 @@ void cMenuHandler :: Set_Active( int num )
 		{
 			items[active]->Set_Active( 0 );
 		}
-
-		if( !items[num]->isquit )
-		{
-			ground->Set_Image( image_ground );
-		}
-		if( items[num]->isquit && use_quit_image )
-		{
-			ground->Set_Image( image_ground_quit );
-		}
 	}
 	else if( num == -1 )
 	{
@@ -220,11 +283,6 @@ void cMenuHandler :: Set_Active( int num )
 	}
 }
 
-void cMenuHandler :: Use_Quit_Image( bool enabled /* = 1 */ )
-{
-	use_quit_image = enabled;
-}
-
 void cMenuHandler :: Update_Mouse( void )
 {
 	int found = -1;
@@ -248,19 +306,19 @@ void cMenuHandler :: Update_Mouse( void )
 	Set_Active( found );
 }
 
-void cMenuHandler :: Draw( void )
+void cMenuHandler :: Draw( bool with_background /* = 1 */ )
 {
-	// Gradient
-	pVideo->Draw_Gradient( NULL, 0.08f, &color_start, &color_end, DIR_VERTICAL );
+	if( with_background )
+	{
+		// Gradient
+		pVideo->Draw_Gradient( NULL, 0.0001f, &color_start, &color_end, DIR_VERTICAL );
 
-	// Logo Image
-	logo->Draw();
-	// Ground Image
-	ground->Draw();
-	// Moon Image
-	moon->Draw();
-	// Background Image
-	background->Draw();
+		// Draw images
+		for( HudSpriteList::iterator itr = images.begin(), itr_end = images.end(); itr != itr_end; ++itr )
+		{
+			(*itr)->Draw();
+		}
+	}
 
 	// menu items
 	for( MenuList::iterator itr = items.begin(), itr_end = items.end(); itr != itr_end; ++itr )
@@ -288,21 +346,23 @@ unsigned int cMenuHandler :: Get_Size( void )
 
 cMenuCore :: cMenuCore( void )
 {
+	menu_id = MENU_NOTHING;
 	next_menu = MENU_NOTHING;
 	options_menu_id = MENU_GAME;
 
+	camera = new cCamera();
 	pMenu_Data = NULL;
-	
 	handler = new cMenuHandler();
 
 	// particle animation
-	pMenu_AnimManager = new cAnimationManager();
+	pMenu_AnimManager = new cAnimation_Manager();
 
 	// left side
-	cParticleAnimation *anim = new cParticleAnimation( -100, 0, 0, GAME_RES_H * 0.5f );
+	cParticle_Emitter *anim = new cParticle_Emitter();
+	anim->Set_Emitter_Rect( -100, 0, 0, game_res_h * 0.5f );
 	anim->Set_Emitter_Time_to_Live( -1 );
 	anim->Set_Emitter_Iteration_Interval( 6 );
-	anim->Set_DirectionRange( 350, 20 );
+	anim->Set_Direction_Range( 350, 20 );
 	anim->Set_Image( pVideo->Get_Surface( "clouds/default_1/1_middle.png" ) );
 	anim->Set_Time_to_Live( 400 );
 	anim->Set_Fading_Alpha( 0 );
@@ -310,15 +370,16 @@ cMenuCore :: cMenuCore( void )
 	anim->Set_Scale( 0.4f, 0.15f );
 	anim->Set_Color( Color( static_cast<Uint8>(220), 240, 255 ), Color( static_cast<Uint8>(25), 5, 0 ) );
 	anim->Set_Speed( 0.1f, 0.01f );
-	anim->Set_ZPos( 0.105f );
+	anim->Set_Pos_Z( 0.0905f );
 
 	pMenu_AnimManager->Add( anim );
 
 	// right side
-	anim = new cParticleAnimation( GAME_RES_W + 100, 0, 0, GAME_RES_H * 0.5f );
+	anim = new cParticle_Emitter();
+	anim->Set_Emitter_Rect( static_cast<float>(game_res_w) + 100, 0, 0, static_cast<float>(game_res_h) * 0.5f );
 	anim->Set_Emitter_Time_to_Live( -1 );
 	anim->Set_Emitter_Iteration_Interval( 6 );
-	anim->Set_DirectionRange( 170, 20 );
+	anim->Set_Direction_Range( 170, 20 );
 	anim->Set_Image( pVideo->Get_Surface( "clouds/default_1/1_middle.png" ) );
 	anim->Set_Time_to_Live( 400 );
 	anim->Set_Fading_Alpha( 0 );
@@ -326,7 +387,7 @@ cMenuCore :: cMenuCore( void )
 	anim->Set_Scale( 0.4f, 0.15f );
 	anim->Set_Color( Color( static_cast<Uint8>(220), 240, 255 ), Color( static_cast<Uint8>(25), 5, 0 ) );
 	anim->Set_Speed( 0.1f, 0.01f );
-	anim->Set_ZPos( 0.105f );
+	anim->Set_Pos_Z( 0.0905f );
 
 	pMenu_AnimManager->Add( anim );
 }
@@ -335,6 +396,7 @@ cMenuCore :: ~cMenuCore( void )
 {
 	Unload();
 
+	delete camera;
 	delete handler;
 	delete pMenu_AnimManager;
 }
@@ -397,14 +459,14 @@ bool cMenuCore :: Key_Down( SDLKey key )
 		// random level name
 		string lvl_name;
 
-		if( !WindowManager::getSingleton().isWindowPresent( "listbox_levels" ) )
+		if( !CEGUI::WindowManager::getSingleton().isWindowPresent( "listbox_levels" ) )
 		{
 			// Create virtual start menu
 			cMenu_Start *menu_start = new cMenu_Start();
 
 			menu_start->Init();
 			// Get Levels Listbox
-			Listbox *listbox_levels = static_cast<Listbox *>(WindowManager::getSingleton().getWindow( "listbox_levels" ));
+			CEGUI::Listbox *listbox_levels = static_cast<CEGUI::Listbox *>(CEGUI::WindowManager::getSingleton().getWindow( "listbox_levels" ));
 			// select random level
 			listbox_levels->setItemSelectState( rand() % listbox_levels->getItemCount(), 1 );
 			// get level name
@@ -415,7 +477,7 @@ bool cMenuCore :: Key_Down( SDLKey key )
 		else
 		{
 			// Get Levels Listbox
-			Listbox *listbox_levels = static_cast<Listbox *>(WindowManager::getSingleton().getWindow( "listbox_levels" ));
+			CEGUI::Listbox *listbox_levels = static_cast<CEGUI::Listbox *>(CEGUI::WindowManager::getSingleton().getWindow( "listbox_levels" ));
 			// select random level
 			listbox_levels->setItemSelectState( rand() % listbox_levels->getItemCount(), 1 );
 			// get level name
@@ -556,51 +618,56 @@ cMenu_Item *cMenuCore :: Auto_Menu( string imagename, string imagefilename_menu,
 	}
 
 	// Position and initialization
-	temp_item->Set_Pos( ( GAME_RES_W / 2 ) - ( temp_item->image_default->col_rect.w / 2 ), ypos );
+	temp_item->Set_Pos( ( game_res_w / 2 ) - ( temp_item->image_default->col_rect.w / 2 ), ypos );
 	temp_item->isquit = is_quit;
 
 	return temp_item;
 }
 
-void cMenuCore :: Load( MenuID menu /* = MENU_MAIN */ )
+void cMenuCore :: Load( MenuID menu /* = MENU_MAIN */, GameMode exit_gamemode /* = MODE_NOTHING */ )
 {
 	Unload();
+	// reset menu handler
+	handler->Reset();
 
 	// unload level if possible
-	if( pLevel->delayed_unload )
+	if( pActive_Level->delayed_unload )
 	{
-		pLevel->Unload();
+		pActive_Level->Unload();
 	}
 
-	// Set ID
-	menu_id = menu;
+	// clear mouse active object
+	pMouseCursor->Double_Click( 0 );
 
-	// check if not entering from another menu
+	// default background color to white
+	glClearColor( 1, 1, 1, 1 );
+
+	// if not entering from another menu
 	if( next_menu == MENU_NOTHING )
 	{
 		// clear animations
-		static_cast<cParticleAnimation *>(pMenu_AnimManager->objects[0])->Clear();
+		static_cast<cParticle_Emitter *>(pMenu_AnimManager->objects[0])->Clear();
+
+		// set camera position
+		camera->Set_Pos( 0, 0 );
 
 		// pre render
 		pFramerate->speedfactor = 2;
 
-		for( unsigned int i = 0; i < DESIRED_FPS * 100; i++ )
+		for( unsigned int i = 0; i < speedfactor_fps * 100; i++ )
 		{
 			pMenu_AnimManager->Update();
 		}
 
 		pFramerate->Update();
 	}
-	
-	next_menu = MENU_NOTHING;
+	else
+	{
+		next_menu = MENU_NOTHING;
+	}
 
-	// clear mouse active object
-	pMouseCursor->Double_Click( 0 );
-
-	handler->Reset();
-
-	// default white background
-	glClearColor( 1, 1, 1, 1 );
+	// Set ID
+	menu_id = menu;
 
 	// ## Create menu class
 	// Main
@@ -653,6 +720,7 @@ void cMenuCore :: Load( MenuID menu /* = MENU_MAIN */ )
 		pMenu_Data = static_cast<cMenu_Base *>(new cMenu_Credits());
 	}
 
+	pMenu_Data->Set_Exit_To_Game_Mode( exit_gamemode );
 	pMenu_Data->Init();
 }
 
@@ -689,7 +757,7 @@ void cMenuCore :: Draw( void )
 	// if no vsync limit the fps for not stressing CPU usage
 	if( !pPreferences->video_vsync )
 	{
-		CorrectFrameTime( 100 );
+		Correct_Frame_Time( 100 );
 	}
 }
 
