@@ -1,7 +1,7 @@
 /***************************************************************************
-                menu.h  -  header for the corresponding cpp file
-                             -------------------
-    copyright            :	(C) 2003 - 2007 by Florian Richter
+ * menu.h  -  header for the corresponding cpp file
+ *
+ * Copyright (C) 2003 - 2008 Florian Richter
  ***************************************************************************/
 /*
    This program is free software; you can redistribute it and/or modify
@@ -13,16 +13,20 @@
    along with this program.  If not, see <http://www.gnu.org/licenses/>.
 */
 
-#ifndef __MENU_H__
-#define __MENU_H__
+#ifndef SMC_MENU_H
+#define SMC_MENU_H
 
 #include "../core/globals.h"
 #include "../video/animation.h"
 #include "../video/video.h"
 #include "../gui/hud.h"
+#include "../core/camera.h"
 
 /* *** *** *** *** *** *** *** Menu Types *** *** *** *** *** *** *** *** *** *** */
 
+namespace SMC
+{ // work around conflicts caused by lack of namespace use in smc
+
 enum MenuID
 {
 	MENU_NOTHING = 0,
@@ -41,6 +45,8 @@ enum OptionMenuID
 	MENU_AUDIO = 2,
 	MENU_CONTROLS = 3
 };
+}
+using namespace SMC;
 
 /* *** *** *** *** *** *** cMenu_Item *** *** *** *** *** *** *** *** *** *** *** */
 
@@ -62,6 +68,7 @@ public:
 	
 	// if this item quits the menu
 	bool isquit;
+
 private:
 	// Is this Item active
 	bool active;
@@ -81,7 +88,7 @@ public:
 	~cMenuHandler( void );
 
 	// Adds a Menu
-	void Add_MenuItem( cMenu_Item *item, float shadow_pos = 0, Color shadow_color = static_cast<Uint8>(0) );
+	void Add_Menu_Item( cMenu_Item *item, float shadow_pos = 0, Color shadow_color = static_cast<Uint8>(0) );
 
 	// Unloads all items
 	void Reset( void );
@@ -91,28 +98,20 @@ public:
 	*/
 	void Set_Active( int num );
 
-	// Set if quit ground image is used
-	void Use_Quit_Image( bool enabled = 1 );
-
 	// Updates the Menu Mouse Collision detection
 	void Update_Mouse( void );
-	// Draws the Menu
-	void Draw( void );
+	// Draw the Menu
+	void Draw( bool with_background = 1 );
 
 	// Returns the currently active Menu Item
 	cMenu_Item *Get_Active_Item( void );
 	// Returns the number of loaded Menus
 	unsigned int Get_Size( void );
 
-	// Logo images
-	GL_Surface *image_ground;
-	GL_Surface *image_ground_quit;
-	// Logo Sprite
-	cHudSprite *logo;
-	// background Sprites
-	cHudSprite *ground;
-	cHudSprite *moon;
-	cHudSprite *background;
+	// menu image sprites
+	typedef vector<cHudSprite *> HudSpriteList;
+	HudSpriteList images;
+
 	// Gradient Colors
 	Color color_start;
 	Color color_end;
@@ -121,11 +120,9 @@ public:
 	* if set to -1 nothing is active
 	*/
 	int active;
+
 private:
 	MenuList items;
-
-	// if quit ground image is allowed
-	bool use_quit_image;
 };
 
 /* *** *** *** *** *** *** *** *** *** *** *** *** *** *** *** *** *** */
@@ -167,8 +164,10 @@ public:
 	// Returns a Menu with the common image filenames
 	cMenu_Item *Auto_Menu( string imagename, string imagename_menu, float ypos = 0, bool is_quit = 0 );
 
-	// Load the given Menu
-	void Load( MenuID menu = MENU_MAIN );
+	/* Load the given Menu
+	 * exit_gamemode : return to this game mode on exit
+	*/
+	void Load( MenuID menu = MENU_MAIN, GameMode exit_gamemode = MODE_NOTHING );
 	// Unload
 	void Unload( void );
 
@@ -184,13 +183,15 @@ public:
 	// the current option menu
 	OptionMenuID options_menu_id;
 
+	// menu camera
+	cCamera *camera;
 	// Menu class
 	cMenu_Base *pMenu_Data;
 
 	// Menu handler
 	cMenuHandler *handler;
 	// Menu Animation Manager
-	cAnimationManager *pMenu_AnimManager;
+	cAnimation_Manager *pMenu_AnimManager;
 };
 
 /* *** *** *** *** *** *** *** *** *** *** *** *** *** *** *** *** *** */
