@@ -1,7 +1,7 @@
 /***************************************************************************
-                level_background.h  -  header for the corresponding cpp file
-                             -------------------
-    copyright            :	(C) 2005 - 2007 by Florian Richter
+ * level_background.h  -  header for the corresponding cpp file
+ *
+ * Copyright (C) 2005 - 2008 Florian Richter
  ***************************************************************************/
 /*
    This program is free software; you can redistribute it and/or modify
@@ -13,20 +13,21 @@
    along with this program.  If not, see <http://www.gnu.org/licenses/>.
 */
 
-#ifndef __LEVEL_BACKGROUND_H__
-#define __LEVEL_BACKGROUND_H__
+#ifndef SMC_LEVEL_BACKGROUND_H
+#define SMC_LEVEL_BACKGROUND_H
 
 #include "../core/globals.h"
 #include "../video/video.h"
+#include "../core/obj_manager.h"
 
 /* *** *** *** *** *** *** *** Background Image Type *** *** *** *** *** *** *** *** *** *** */
 
 enum BackgroundType
 {
 	BG_NONE = 0,			// no background type
-	BG_IMG_LEFTRIGHT = 1,	// only to the horizontal
+	BG_IMG_BOTTOM = 1,		// only horizontal on the bottom
 	BG_IMG_ALL = 2,			// into all directions
-	BG_IMG_TOP = 3,			// is always on top
+	BG_IMG_TOP = 3,			// only horizontal on top
 	BG_GR_VER = 103,		// Gradient Vertical
 	BG_GR_HOR = 104			// Gradient Horizontal
 };
@@ -39,7 +40,7 @@ public:
 	// default constructor
 	cBackground( void );
 	// create from stream
-	cBackground( XMLAttributes &attributes );
+	cBackground( CEGUI::XMLAttributes &attributes );
 	// destructor
 	~cBackground( void );
 
@@ -47,47 +48,69 @@ public:
 	void Init( void );
 
 	// create from stream
-	void Create_from_Stream( XMLAttributes &attributes );
+	void Create_from_Stream( CEGUI::XMLAttributes &attributes );
 	// save to stream
 	void Save_to_Stream( ofstream &file );
 
 	// Sets the type of Background
-	void Set_type( BackgroundType ntype );
-	void Set_type( string ntype );
+	void Set_Type( BackgroundType ntype );
+	void Set_Type( string ntype );
 
 	// Sets the background color
-	void Set_color_1( const Color &color );
-	void Set_color_2( const Color &color );
+	void Set_Color_1( const Color &color );
+	void Set_Color_2( const Color &color );
 
+	// Set the Position
+	void Set_Pos( float x, float y );
+	// Set the Position z
+	void Set_Pos_Z( float val );
 	// Set the Background image
-	void Set_image( string nimg_file_1 );
+	void Set_Image( string nimg_file_1 );
 	// Set the Background Image scrolling speed
-	void Set_scroll_speed( float x = 1, float y = 1 );
-	// Set the Position Z
-	void Set_PosZ( float val );
+	void Set_Scroll_Speed( float x = 1, float y = 1 );
 
+	// Set constant x velocity
+	void Set_Const_Velocity_X( float vel );
+	// Set constant y velocity
+	void Set_Const_Velocity_Y( float vel );
+
+	// Update
+	void Update( void );
+	// draw
 	void Draw( void );
-	void DrawGradient( void );
+	// draw gradient
+	void Draw_Gradient( void );
 
 	// Returns the name of the current type
-	string Get_Typename( void );
+	string Get_Type_Name( void );
 
 	// type
 	BackgroundType type;
-
-	// background image filename
-	string img_file_1;
-	// background image
-	GL_Surface *img_1;
-
 	// position
 	float posx, posy, posz;
 
-	// background image scrolling speed
+	// - background image settings
+	// image
+	cGL_Surface *img_1;
+	// image filename
+	string img_file_1;
+	// scrolling speed
 	float speedx, speedy;
+	// constant velocity
+	float const_velx, const_vely;
 
-	// background gradient colors
+	// - background gradient settings
+	// colors
 	Color color_1, color_2;
 };
 
+/* *** *** *** *** *** cBackground_Manager *** *** *** *** *** *** *** *** *** *** *** *** */
+
+class cBackground_Manager : public cObject_Manager<cBackground>
+{
+public:
+	cBackground_Manager( void );
+	virtual ~cBackground_Manager( void );
+};
+
 #endif
