@@ -1,7 +1,7 @@
 /***************************************************************************
-			level_editor.h  -  header for the corresponding cpp file
-                             -------------------
-    copyright            : (C) 2006 - 2007 by Florian Richter
+ * level_editor.h  -  header for the corresponding cpp file
+ *
+ * Copyright (C) 2006 - 2008 Florian Richter
  ***************************************************************************/
 /*
    This program is free software; you can redistribute it and/or modify
@@ -13,10 +13,11 @@
    along with this program.  If not, see <http://www.gnu.org/licenses/>.
 */
 
-#ifndef __LEVEL_EDITOR_H__
-#define __LEVEL_EDITOR_H__
+#ifndef SMC_LEVEL_EDITOR_H
+#define SMC_LEVEL_EDITOR_H
 
 #include "../core/editor.h"
+#include "../level/level_settings.h"
 
 /* *** *** *** *** *** *** *** cEditor_Level *** *** *** *** *** *** *** *** *** *** */
 
@@ -41,17 +42,14 @@ public:
 	*/
 	virtual bool Key_Down( SDLKey key );
 
-	// Add Object to Level
-	virtual void Add_Object( cSprite *object );
-
 	// Set Active Menu Entry
-	virtual void Activate_Menu( cEditor_Menu_Object *entry );
+	virtual void Activate_Menu_Item( cEditor_Menu_Object *entry );
 
 	// #### LevelEditor Functions
 	/* switch the object state of the given object
 	 * returns true if successful
 	*/
-	bool Switch_ObjectState( cSprite *obj );
+	bool Switch_Object_State( cSprite *obj );
 
 	// Menu functions
 	virtual bool Function_New( void );
