@@ -1,7 +1,7 @@
 /***************************************************************************
-                objectsprite.h  -  header for the corresponding cpp file
-                             -------------------
-    copyright            :	(C) 2005 - 2007 by Florian Richter
+ * objectsprite.h  -  header for the corresponding cpp file
+ *
+ * Copyright (C) 2005 - 2008 Florian Richter
  ***************************************************************************/
 /*
    This program is free software; you can redistribute it and/or modify
@@ -13,8 +13,8 @@
    along with this program.  If not, see <http://www.gnu.org/licenses/>.
 */
 
-#ifndef __OBJECTSPRITE_H__
-#define __OBJECTSPRITE_H__
+#ifndef SMC_OBJECTSPRITE_H
+#define SMC_OBJECTSPRITE_H
 
 #include "../objects/movingsprite.h"
 
@@ -32,14 +32,14 @@ public:
 	*/
 	virtual void Set_Image( int num, bool new_startimage = 0, bool del_img = 0 );
 	// Get an array image
-	GL_Surface *Get_Image( unsigned int num );
+	cGL_Surface *Get_Image( unsigned int num );
 	// Clears images list
 	void Clear_Images( void );
 
 	// Current image array number for drawing
 	int curr_img;
 	// Image list
-	typedef vector<GL_Surface *> ObjectImageList;
+	typedef vector<cGL_Surface *> ObjectImageList;
 	ObjectImageList images;
 };
 
