@@ -1,7 +1,7 @@
 /***************************************************************************
-                star.h  -  header for the corresponding cpp file
-                             -------------------
-    copyright            :	(C) 2006 - 2007 by Florian Richter
+ * star.h  -  header for the corresponding cpp file
+ *
+ * Copyright (C) 2006 - 2008 Florian Richter
  ***************************************************************************/
 /*
    This program is free software; you can redistribute it and/or modify
@@ -13,8 +13,8 @@
    along with this program.  If not, see <http://www.gnu.org/licenses/>.
 */
 
-#ifndef __STAR_H__
-#define __STAR_H__
+#ifndef SMC_STAR_H
+#define SMC_STAR_H
 
 #include "../core/globals.h"
 #include "../objects/powerup.h"
